@@ -17,19 +17,23 @@
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """The agri_l1 reader tests package."""
 
-from satpy.tests.reader_tests.test_hdf5_utils import FakeHDF5FileHandler
-import numpy as np
-import dask.array as da
-import xarray as xr
 import os
 import unittest
 from unittest import mock
 
+import dask.array as da
+import numpy as np
+import pytest
+import xarray as xr
+
+from satpy.tests.reader_tests.test_hdf5_utils import FakeHDF5FileHandler
+
 
 class FakeHDF5FileHandler2(FakeHDF5FileHandler):
     """Swap-in HDF5 File Handler."""
 
     def make_test_data(self, cwl, ch, prefix, dims, file_type):
+        """Make test data."""
         if prefix == 'CAL':
             data = xr.DataArray(
                                 da.from_array((np.arange(10.) + 1.) / 10., [dims[0] * dims[1]]),
@@ -123,7 +127,7 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
         chs = [2]
         cwls = [0.65]
         data = {}
-        for index, cwl in enumerate(cwls):
+        for index, _cwl in enumerate(cwls):
             data['CALChannel' + '%02d' % chs[index]] = self.make_test_data(cwls[index], chs[index], 'CAL',
                                                                            [dim_0, dim_1], file_type)
             data['NOMChannel' + '%02d' % chs[index]] = self.make_test_data(cwls[index], chs[index], 'NOM',
@@ -139,7 +143,7 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
         chs = np.linspace(1, 3, 3)
         cwls = [0.47, 0.65, 0.83]
         data = {}
-        for index, cwl in enumerate(cwls):
+        for index, _cwl in enumerate(cwls):
             data['CALChannel' + '%02d' % chs[index]] = self.make_test_data(cwls[index], chs[index], 'CAL',
                                                                            [dim_0, dim_1], file_type)
             data['NOMChannel' + '%02d' % chs[index]] = self.make_test_data(cwls[index], chs[index], 'NOM',
@@ -155,7 +159,7 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
         chs = np.linspace(1, 7, 7)
         cwls = [0.47, 0.65, 0.83, 1.37, 1.61, 2.22, 3.72]
         data = {}
-        for index, cwl in enumerate(cwls):
+        for index, _cwl in enumerate(cwls):
             data['CALChannel' + '%02d' % chs[index]] = self.make_test_data(cwls[index], chs[index], 'CAL',
                                                                            [dim_0, dim_1], file_type)
             data['NOMChannel' + '%02d' % chs[index]] = self.make_test_data(cwls[index], chs[index], 'NOM',
@@ -171,7 +175,7 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
         chs = np.linspace(1, 14, 14)
         cwls = [0.47, 0.65, 0.83, 1.37, 1.61, 2.22, 3.72, 3.72, 6.25, 7.10, 8.50, 10.8, 12, 13.5]
         data = {}
-        for index, cwl in enumerate(cwls):
+        for index, _cwl in enumerate(cwls):
             data['CALChannel' + '%02d' % chs[index]] = self.make_test_data(cwls[index], chs[index], 'CAL',
                                                                            [dim_0, dim_1], file_type)
             data['NOMChannel' + '%02d' % chs[index]] = self.make_test_data(cwls[index], chs[index], 'NOM',
@@ -184,10 +188,16 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
     def get_test_content(self, filename, filename_info, filetype_info):
         """Mimic reader input file content."""
         global_attrs = {
-            '/attr/NOMCenterLat': 0.0, '/attr/NOMCenterLon': 104.7, '/attr/NOMSatHeight': 3.5786E7,
-            '/attr/dEA': 6378.14, '/attr/dObRecFlat': 298.257223563,
-            '/attr/OBIType': 'REGC', '/attr/RegLength': 2.0, '/attr/RegWidth': 5.0,
-            '/attr/Begin Line Number': 0, '/attr/End Line Number': 1,
+            '/attr/NOMCenterLat': np.array(0.0),
+            '/attr/NOMCenterLon': np.array(104.7),
+            '/attr/NOMSatHeight': np.array(3.5786E7),
+            '/attr/dEA': np.array(6378.14),
+            '/attr/dObRecFlat': np.array(298.257223563),
+            '/attr/OBIType': 'REGC',
+            '/attr/RegLength': np.array(2.0),
+            '/attr/RegWidth': np.array(5.0),
+            '/attr/Begin Line Number': np.array(0),
+            '/attr/End Line Number': np.array(1),
             '/attr/Observing Beginning Date': '2019-06-03', '/attr/Observing Beginning Time': '00:30:01.807',
             '/attr/Observing Ending Date': '2019-06-03', '/attr/Observing Ending Time': '00:34:07.572',
             '/attr/Satellite Name': 'FY4A', '/attr/Sensor Identification Code': 'AGRI', '/attr/Sensor Name': 'AGRI',
@@ -212,6 +222,7 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
 
 class Test_HDF_AGRI_L1_cal(unittest.TestCase):
     """Test VIRR L1B Reader."""
+
     yaml_file = "agri_l1.yaml"
 
     def setUp(self):
@@ -230,8 +241,9 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
 
     def test_fy4a_all_resolutions(self):
         """Test loading data when all resolutions are available."""
-        from satpy import DatasetID
-        from satpy.readers import load_reader, get_key
+        from satpy.tests.utils import make_dsq
+        from satpy.readers import load_reader
+        from satpy.dataset.data_dict import get_key
         filenames = [
             'FY4A-_AGRI--_N_REGC_1047E_L1-_FDI-_MULT_NOM_20190603003000_20190603003416_0500M_V0001.HDF',
             'FY4A-_AGRI--_N_REGC_1047E_L1-_FDI-_MULT_NOM_20190603003000_20190603003416_1000M_V0001.HDF',
@@ -240,7 +252,7 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
         ]
         reader = load_reader(self.reader_configs)
         files = reader.select_files_from_pathnames(filenames)
-        self.assertTrue(4, len(files))
+        self.assertEqual(4, len(files))
         reader.create_filehandlers(files)
         # Make sure we have some files
         self.assertTrue(reader.file_handlers)
@@ -250,22 +262,22 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
         # 500m
         band_names = ['C' + '%02d' % ch for ch in np.linspace(2, 2, 1)]
         for band_name in band_names:
-            ds_id = DatasetID(name=band_name, resolution=500)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
+            ds_q = make_dsq(name=band_name, resolution=500)
+            res = get_key(ds_q, available_datasets, num_results=0, best=False)
             self.assertEqual(2, len(res))
 
         # 1km
         band_names = ['C' + '%02d' % ch for ch in np.linspace(1, 3, 3)]
         for band_name in band_names:
-            ds_id = DatasetID(name=band_name, resolution=1000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
+            ds_q = make_dsq(name=band_name, resolution=1000)
+            res = get_key(ds_q, available_datasets, num_results=0, best=False)
             self.assertEqual(2, len(res))
 
         # 2km
         band_names = ['C' + '%02d' % ch for ch in np.linspace(1, 7, 7)]
         for band_name in band_names:
-            ds_id = DatasetID(name=band_name, resolution=2000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
+            ds_q = make_dsq(name=band_name, resolution=2000)
+            res = get_key(ds_q, available_datasets, num_results=0, best=False)
             if band_name < 'C07':
                 self.assertEqual(2, len(res))
             else:
@@ -286,9 +298,17 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
             else:
                 self.assertEqual('K', res[band_name].attrs['units'])
 
+        # check whether the data type of orbital_parameters is float
+        orbital_parameters = res[band_names[0]].attrs['orbital_parameters']
+        for attr in orbital_parameters:
+            self.assertEqual(type(orbital_parameters[attr]), float)
+        self.assertEqual(orbital_parameters['satellite_nominal_latitude'], 0.)
+        self.assertEqual(orbital_parameters['satellite_nominal_longitude'], 104.7)
+        self.assertEqual(orbital_parameters['satellite_nominal_altitude'], 3.5786E7)
+
     def test_fy4a_counts_calib(self):
         """Test loading data at counts calibration."""
-        from satpy import DatasetID
+        from satpy.tests.utils import make_dsq
         from satpy.readers import load_reader
         filenames = [
             'FY4A-_AGRI--_N_REGC_1047E_L1-_FDI-_MULT_NOM_20190603003000_20190603003416_0500M_V0001.HDF',
@@ -298,7 +318,7 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
         ]
         reader = load_reader(self.reader_configs)
         files = reader.select_files_from_pathnames(filenames)
-        self.assertTrue(4, len(files))
+        self.assertEqual(4, len(files))
         reader.create_filehandlers(files)
         # Make sure we have some files
         self.assertTrue(reader.file_handlers)
@@ -306,7 +326,7 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
         ds_ids = []
         band_names = ['C' + '%02d' % ch for ch in np.linspace(1, 14, 14)]
         for band_name in band_names:
-            ds_ids.append(DatasetID(name=band_name, calibration='counts'))
+            ds_ids.append(make_dsq(name=band_name, calibration='counts'))
         res = reader.load(ds_ids)
         self.assertEqual(14, len(res))
 
@@ -318,14 +338,15 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
 
     def test_fy4a_4km_resolutions(self):
         """Test loading data when only 4km resolutions are available."""
-        from satpy import DatasetID
-        from satpy.readers import load_reader, get_key
+        from satpy.tests.utils import make_dsq
+        from satpy.readers import load_reader
+        from satpy.dataset.data_dict import get_key
         filenames = [
             'FY4A-_AGRI--_N_REGC_1047E_L1-_FDI-_MULT_NOM_20190603003000_20190603003416_4000M_V0001.HDF',
         ]
         reader = load_reader(self.reader_configs)
         files = reader.select_files_from_pathnames(filenames)
-        self.assertTrue(1, len(files))
+        self.assertEqual(1, len(files))
         reader.create_filehandlers(files)
         # Make sure we have some files
         self.assertTrue(reader.file_handlers)
@@ -333,19 +354,14 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
         # Verify that the resolution is only 4km
         available_datasets = reader.available_dataset_ids
         band_names = ['C' + '%02d' % ch for ch in np.linspace(1, 14, 14)]
-
         for band_name in band_names:
-            ds_id = DatasetID(name=band_name, resolution=500)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
-            self.assertEqual(0, len(res))
-            ds_id = DatasetID(name=band_name, resolution=1000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
-            self.assertEqual(0, len(res))
-            ds_id = DatasetID(name=band_name, resolution=2000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
-            self.assertEqual(0, len(res))
-            ds_id = DatasetID(name=band_name, resolution=4000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
+            for resolution in [500, 1000, 2000]:
+                ds_q = make_dsq(name=band_name, resolution=resolution)
+                with pytest.raises(KeyError):
+                    res = get_key(ds_q, available_datasets, num_results=0, best=False)
+
+            ds_q = make_dsq(name=band_name, resolution=4000)
+            res = get_key(ds_q, available_datasets, num_results=0, best=False)
             if band_name < 'C07':
                 self.assertEqual(2, len(res))
             else:
@@ -378,14 +394,15 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
 
     def test_fy4a_2km_resolutions(self):
         """Test loading data when only 2km resolutions are available."""
-        from satpy import DatasetID
-        from satpy.readers import load_reader, get_key
+        from satpy.tests.utils import make_dsq
+        from satpy.readers import load_reader
+        from satpy.dataset.data_dict import get_key
         filenames = [
             'FY4A-_AGRI--_N_REGC_1047E_L1-_FDI-_MULT_NOM_20190603003000_20190603003416_2000M_V0001.HDF',
         ]
         reader = load_reader(self.reader_configs)
         files = reader.select_files_from_pathnames(filenames)
-        self.assertTrue(1, len(files))
+        self.assertEqual(1, len(files))
         reader.create_filehandlers(files)
         # Make sure we have some files
         self.assertTrue(reader.file_handlers)
@@ -395,21 +412,17 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
         band_names = ['C' + '%02d' % ch for ch in np.linspace(1, 7, 7)]
 
         for band_name in band_names:
-            ds_id = DatasetID(name=band_name, resolution=500)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
-            self.assertEqual(0, len(res))
-            ds_id = DatasetID(name=band_name, resolution=1000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
-            self.assertEqual(0, len(res))
-            ds_id = DatasetID(name=band_name, resolution=2000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
+            for resolution in [500, 1000, 4000]:
+                ds_q = make_dsq(name=band_name, resolution=resolution)
+                with pytest.raises(KeyError):
+                    res = get_key(ds_q, available_datasets, num_results=0, best=False)
+
+            ds_q = make_dsq(name=band_name, resolution=2000)
+            res = get_key(ds_q, available_datasets, num_results=0, best=False)
             if band_name < 'C07':
                 self.assertEqual(2, len(res))
             else:
                 self.assertEqual(3, len(res))
-            ds_id = DatasetID(name=band_name, resolution=4000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
-            self.assertEqual(0, len(res))
 
         res = reader.load(band_names)
         self.assertEqual(7, len(res))
@@ -437,14 +450,15 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
 
     def test_fy4a_1km_resolutions(self):
         """Test loading data when only 1km resolutions are available."""
-        from satpy import DatasetID
-        from satpy.readers import load_reader, get_key
+        from satpy.tests.utils import make_dsq
+        from satpy.readers import load_reader
+        from satpy.dataset.data_dict import get_key
         filenames = [
             'FY4A-_AGRI--_N_REGC_1047E_L1-_FDI-_MULT_NOM_20190603003000_20190603003416_1000M_V0001.HDF',
         ]
         reader = load_reader(self.reader_configs)
         files = reader.select_files_from_pathnames(filenames)
-        self.assertTrue(1, len(files))
+        self.assertEqual(1, len(files))
         reader.create_filehandlers(files)
         # Make sure we have some files
         self.assertTrue(reader.file_handlers)
@@ -454,18 +468,14 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
         band_names = ['C' + '%02d' % ch for ch in np.linspace(1, 3, 3)]
 
         for band_name in band_names:
-            ds_id = DatasetID(name=band_name, resolution=500)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
-            self.assertEqual(0, len(res))
-            ds_id = DatasetID(name=band_name, resolution=1000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
+            for resolution in [500, 2000, 4000]:
+                ds_q = make_dsq(name=band_name, resolution=resolution)
+                with pytest.raises(KeyError):
+                    res = get_key(ds_q, available_datasets, num_results=0, best=False)
+
+            ds_q = make_dsq(name=band_name, resolution=1000)
+            res = get_key(ds_q, available_datasets, num_results=0, best=False)
             self.assertEqual(2, len(res))
-            ds_id = DatasetID(name=band_name, resolution=2000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
-            self.assertEqual(0, len(res))
-            ds_id = DatasetID(name=band_name, resolution=4000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
-            self.assertEqual(0, len(res))
 
         res = reader.load(band_names)
         self.assertEqual(3, len(res))
@@ -484,14 +494,15 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
 
     def test_fy4a_500m_resolutions(self):
         """Test loading data when only 500m resolutions are available."""
-        from satpy import DatasetID
-        from satpy.readers import load_reader, get_key
+        from satpy.tests.utils import make_dsq
+        from satpy.readers import load_reader
+        from satpy.dataset.data_dict import get_key
         filenames = [
             'FY4A-_AGRI--_N_REGC_1047E_L1-_FDI-_MULT_NOM_20190603003000_20190603003416_0500M_V0001.HDF',
         ]
         reader = load_reader(self.reader_configs)
         files = reader.select_files_from_pathnames(filenames)
-        self.assertTrue(1, len(files))
+        self.assertEqual(1, len(files))
         reader.create_filehandlers(files)
         # Make sure we have some files
         self.assertTrue(reader.file_handlers)
@@ -501,18 +512,14 @@ class Test_HDF_AGRI_L1_cal(unittest.TestCase):
         band_names = ['C' + '%02d' % ch for ch in np.linspace(2, 2, 1)]
 
         for band_name in band_names:
-            ds_id = DatasetID(name=band_name, resolution=500)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
+            for resolution in [1000, 2000, 4000]:
+                ds_q = make_dsq(name=band_name, resolution=resolution)
+                with pytest.raises(KeyError):
+                    res = get_key(ds_q, available_datasets, num_results=0, best=False)
+
+            ds_q = make_dsq(name=band_name, resolution=500)
+            res = get_key(ds_q, available_datasets, num_results=0, best=False)
             self.assertEqual(2, len(res))
-            ds_id = DatasetID(name=band_name, resolution=1000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
-            self.assertEqual(0, len(res))
-            ds_id = DatasetID(name=band_name, resolution=2000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
-            self.assertEqual(0, len(res))
-            ds_id = DatasetID(name=band_name, resolution=4000)
-            res = get_key(ds_id, available_datasets, num_results=0, best=False)
-            self.assertEqual(0, len(res))
 
         res = reader.load(band_names)
         self.assertEqual(1, len(res))
