@@ -18,12 +18,12 @@
 """Pygac interface."""
 
 from datetime import datetime
-import dask.array as da
-from unittest import TestCase
-import numpy as np
-import xarray as xr
-from unittest import mock
+from unittest import TestCase, mock
 
+import dask.array as da
+import numpy as np
+import pytest
+import xarray as xr
 
 GAC_PATTERN = '{creation_site:3s}.{transfer_mode:4s}.{platform_id:2s}.D{start_time:%y%j.S%H%M}.E{end_time:%H%M}.B{orbit_number:05d}{end_orbit_last_digits:02d}.{station:2s}'  # noqa
 
@@ -117,9 +117,7 @@ class TestGACLACFile(TestCase):
     def _get_reader_mocked(self, along_track=3):
         """Create a mocked reader."""
         reader = mock.MagicMock(spacecraft_name='spacecraft_name',
-                                meta_data={'foo': 'bar',
-                                           'midnight_scanline': 1,
-                                           'missing_scanlines': [1, 2, 3]})
+                                meta_data={'foo': 'bar'})
         reader.mask = [0, 0]
         reader.get_times.return_value = np.arange(along_track)
         reader.get_tle_lines.return_value = 'tle'
@@ -132,19 +130,30 @@ class TestGACLACFile(TestCase):
         from pygac.lac_klm import LACKLMReader
         from pygac.lac_pod import LACPODReader
 
+        kwargs = {'start_line': 1,
+                  'end_line': 2,
+                  'strip_invalid_coords': True,
+                  'interpolate_coords': True,
+                  'adjust_clock_drift': True,
+                  'tle_dir': 'tle_dir',
+                  'tle_name': 'tle_name',
+                  'tle_thresh': 123,
+                  'calibration': 'calibration'}
         for filenames, reader_cls in zip([GAC_POD_FILENAMES, GAC_KLM_FILENAMES, LAC_POD_FILENAMES, LAC_KLM_FILENAMES],
                                          [GACPODReader, GACKLMReader, LACPODReader, LACKLMReader]):
             for filename in filenames:
-                fh = self._get_fh(filename)
+                fh = self._get_fh(filename, **kwargs)
                 self.assertLess(fh.start_time, fh.end_time,
                                 "Start time must precede end time.")
                 self.assertIs(fh.reader_class, reader_cls,
                               'Wrong reader class assigned to {}'.format(filename))
 
     @mock.patch('satpy.readers.avhrr_l1b_gaclac.GACLACFile.__init__', return_value=None)
+    @mock.patch('satpy.readers.avhrr_l1b_gaclac.GACLACFile.read_raw_data')
     @mock.patch('satpy.readers.avhrr_l1b_gaclac.GACLACFile._get_channel')
     def test_get_dataset_channels(self, get_channel, *mocks):
-        from satpy.dataset import DatasetID
+        """Test getting the channel datasets."""
+        from satpy.tests.utils import make_dataid
 
         # Mock reader and file handler
         fh = self._get_fh_mocked(
@@ -160,7 +169,7 @@ class TestGACLACFile(TestCase):
         # Test calibration to reflectance as well as attributes.
         counts = np.ones((3, 3))
         get_channel.return_value = counts
-        key = DatasetID('1', calibration='reflectance')
+        key = make_dataid(name='1', calibration='reflectance')
         info = {'name': '1', 'standard_name': 'my_standard_name'}
 
         res = fh.get_dataset(key=key, info=info)
@@ -173,8 +182,6 @@ class TestGACLACFile(TestCase):
                                   'orbit_number': 123,
                                   'sensor': 'sensor',
                                   'orbital_parameters': {'tle': 'tle'},
-                                  'midnight_scanline': 1,
-                                  'missing_scanlines': [1, 2, 3],
                                   'foo': 'bar',
                                   'standard_name': 'my_standard_name'})
         exp.coords['acq_time'].attrs['long_name'] = 'Mean scanline acquisition time'
@@ -182,16 +189,39 @@ class TestGACLACFile(TestCase):
         get_channel.assert_called_with(key)
 
         # Counts & brightness temperature: Similar, just check _get_channel() call
-        for key in [DatasetID('1', calibration='counts'),
-                    DatasetID('5', calibration='brightness_temperature')]:
+        for key in [make_dataid(name='1', calibration='counts'),
+                    make_dataid(name='5', calibration='brightness_temperature')]:
             fh.get_dataset(key=key, info={'name': 1})
             get_channel.assert_called_with(key)
 
+    def test_read_raw_data(self):
+        """Test raw data reading."""
+        fh = self._get_fh_mocked(reader=None,
+                                 interpolate_coords='interpolate_coords',
+                                 creation_site='creation_site',
+                                 reader_kwargs={'foo': 'bar'},
+                                 filename='myfile')
+        reader = mock.MagicMock(mask=[0])
+        reader_cls = mock.MagicMock(return_value=reader)
+        fh.reader_class = reader_cls
+        fh.read_raw_data()
+        reader_cls.assert_called_with(interpolate_coords='interpolate_coords',
+                                      creation_site='creation_site',
+                                      foo='bar')
+        reader.read.assert_called_with('myfile')
+
+        # Test exception if all data is masked
+        reader.mask = [1]
+        fh.reader = None
+        with self.assertRaises(ValueError):
+            fh.read_raw_data()
+
     @mock.patch('satpy.readers.avhrr_l1b_gaclac.GACLACFile._update_attrs')
     @mock.patch('satpy.readers.avhrr_l1b_gaclac.GACLACFile.slice')
     @mock.patch('satpy.readers.avhrr_l1b_gaclac.GACLACFile._get_channel')
     def test_get_dataset_slice(self, get_channel, slc, *mocks):
-        from satpy.dataset import DatasetID
+        """Get a slice of a dataset."""
+        from satpy.tests.utils import make_dataid
 
         # Test slicing/stripping
         def slice_patched(data, times):
@@ -220,7 +250,7 @@ class TestGACLACFile(TestCase):
                 **kwargs
             )
 
-            key = DatasetID('1', calibration='reflectance')
+            key = make_dataid(name='1', calibration='reflectance')
             info = {'name': '1', 'standard_name': 'reflectance'}
             res = fh.get_dataset(key, info)
             np.testing.assert_array_equal(res.data, ch[1:3, :])
@@ -230,7 +260,8 @@ class TestGACLACFile(TestCase):
 
     @mock.patch('satpy.readers.avhrr_l1b_gaclac.GACLACFile._update_attrs')
     def test_get_dataset_latlon(self, *mocks):
-        from satpy.dataset import DatasetID
+        """Test getting the latitudes and longitudes."""
+        from satpy.tests.utils import make_dataid
 
         lons = np.ones((3, 3))
         lats = 2 * lons
@@ -246,7 +277,7 @@ class TestGACLACFile(TestCase):
 
         # With interpolation of coordinates
         for name, exp_data in zip(['longitude', 'latitude'], [lons, lats]):
-            key = DatasetID(name)
+            key = make_dataid(name=name)
             info = {'name': name, 'standard_name': 'my_standard_name'}
             res = fh.get_dataset(key=key, info=info)
             exp = xr.DataArray(exp_data,
@@ -257,8 +288,8 @@ class TestGACLACFile(TestCase):
 
         # Without interpolation of coordinates
         fh.interpolate_coords = False
-        for name, exp_data in zip(['longitude', 'latitude'], [lons, lats]):
-            key = DatasetID(name)
+        for name, _exp_data in zip(['longitude', 'latitude'], [lons, lats]):
+            key = make_dataid(name=name)
             info = {'name': name, 'standard_name': 'my_standard_name'}
             res = fh.get_dataset(key=key, info=info)
             self.assertTupleEqual(res.dims, ('y', 'x_every_eighth'))
@@ -266,7 +297,8 @@ class TestGACLACFile(TestCase):
     @mock.patch('satpy.readers.avhrr_l1b_gaclac.GACLACFile._update_attrs')
     @mock.patch('satpy.readers.avhrr_l1b_gaclac.GACLACFile._get_angle')
     def test_get_dataset_angles(self, get_angle, *mocks):
-        from satpy.dataset import DatasetID
+        """Test getting the angles."""
+        from satpy.tests.utils import make_dataid
         from satpy.readers.avhrr_l1b_gaclac import ANGLES
 
         ones = np.ones((3, 3))
@@ -282,7 +314,7 @@ class TestGACLACFile(TestCase):
 
         # With interpolation of coordinates
         for angle in ANGLES:
-            key = DatasetID(angle)
+            key = make_dataid(name=angle)
             info = {'name': angle, 'standard_name': 'my_standard_name'}
             res = fh.get_dataset(key=key, info=info)
             exp = xr.DataArray(ones,
@@ -294,14 +326,15 @@ class TestGACLACFile(TestCase):
         # Without interpolation of coordinates
         fh.interpolate_coords = False
         for angle in ANGLES:
-            key = DatasetID(angle)
+            key = make_dataid(name=angle)
             info = {'name': angle, 'standard_name': 'my_standard_name'}
             res = fh.get_dataset(key=key, info=info)
             self.assertTupleEqual(res.dims, ('y', 'x_every_eighth'))
 
     @mock.patch('satpy.readers.avhrr_l1b_gaclac.GACLACFile._update_attrs')
     def test_get_dataset_qual_flags(self, *mocks):
-        from satpy.dataset import DatasetID
+        """Test getting the qualitiy flags."""
+        from satpy.tests.utils import make_dataid
 
         qual_flags = np.ones((3, 7))
         reader = self._get_reader_mocked()
@@ -314,7 +347,7 @@ class TestGACLACFile(TestCase):
             interpolate_coords=True
         )
 
-        key = DatasetID('qual_flags')
+        key = make_dataid(name='qual_flags')
         info = {'name': 'qual_flags'}
         res = fh.get_dataset(key=key, info=info)
         exp = xr.DataArray(qual_flags,
@@ -331,7 +364,8 @@ class TestGACLACFile(TestCase):
         xr.testing.assert_equal(res, exp)
 
     def test_get_channel(self):
-        from satpy.dataset import DatasetID
+        """Test getting the channels."""
+        from satpy.tests.utils import make_dataid
 
         counts = np.moveaxis(np.array([[[1, 2, 3],
                                         [4, 5, 6]]]), 0, 2)
@@ -342,7 +376,7 @@ class TestGACLACFile(TestCase):
         fh = self._get_fh_mocked(reader=reader, counts=None, calib_channels=None,
                                  chn_dict={'1': 0})
 
-        key = DatasetID('1', calibration='counts')
+        key = make_dataid(name='1', calibration='counts')
         # Counts
         res = fh._get_channel(key=key)
         np.testing.assert_array_equal(res, [[1, 2, 3],
@@ -351,38 +385,38 @@ class TestGACLACFile(TestCase):
 
         # Reflectance and Brightness Temperature
         for calib in ['reflectance', 'brightness_temperature']:
-            key = DatasetID('1', calibration=calib)
+            key = make_dataid(name='1', calibration=calib)
             res = fh._get_channel(key=key)
             np.testing.assert_array_equal(res, [[2, 4, 6],
                                                 [8, 10, 12]])
             np.testing.assert_array_equal(fh.calib_channels, calib_channels)
 
         # Invalid
-        key = DatasetID('7', calibration='coffee')
-        self.assertRaises(ValueError, fh._get_channel, key=key)
+        with pytest.raises(ValueError):
+            key = make_dataid(name='7', calibration='coffee')
 
         # Buffering
         reader.get_counts.reset_mock()
-        key = DatasetID('1', calibration='counts')
+        key = make_dataid(name='1', calibration='counts')
         fh._get_channel(key=key)
         reader.get_counts.assert_not_called()
 
         reader.get_calibrated_channels.reset_mock()
         for calib in ['reflectance', 'brightness_temperature']:
-            key = DatasetID('1', calibration=calib)
+            key = make_dataid(name='1', calibration=calib)
             fh._get_channel(key)
             reader.get_calibrated_channels.assert_not_called()
 
     def test_get_angle(self):
         """Test getting the angle."""
-        from satpy.dataset import DatasetID
+        from satpy.tests.utils import make_dataid
 
         reader = mock.MagicMock()
         reader.get_angles.return_value = 1, 2, 3, 4, 5
         fh = self._get_fh_mocked(reader=reader, angles=None)
 
         # Test angle readout
-        key = DatasetID('sensor_zenith_angle')
+        key = make_dataid(name='sensor_zenith_angle')
         res = fh._get_angle(key)
         self.assertEqual(res, 2)
         self.assertDictEqual(fh.angles, {'sensor_zenith_angle': 2,
@@ -392,7 +426,7 @@ class TestGACLACFile(TestCase):
                                          'sun_sensor_azimuth_difference_angle': 5})
 
         # Test buffering
-        key = DatasetID('sensor_azimuth_angle')
+        key = make_dataid(name='sensor_azimuth_angle')
         fh._get_angle(key)
         reader.get_angles.assert_called_once()
 
@@ -416,24 +450,20 @@ class TestGACLACFile(TestCase):
     @mock.patch('satpy.readers.avhrr_l1b_gaclac.GACLACFile._slice')
     def test_slice(self, _slice):
         """Test slicing."""
-        def slice_patched(data):
-            if len(data.shape) == 2:
-                return data[1:3, :], 'midn_line', np.array([1., 2., 3.])
-            return data[1:3], 'foo', np.array([0, 0, 0])
 
-        _slice.side_effect = slice_patched
+        def _slice_patched(data):
+            return data[1:3]
+        _slice.side_effect = _slice_patched
+
         data = np.zeros((4, 2))
         times = np.array([1, 2, 3, 4], dtype='datetime64[us]')
 
-        fh = self._get_fh_mocked()
+        fh = self._get_fh_mocked(start_line=1, end_line=3, strip_invalid_coords=False)
         data_slc, times_slc = fh.slice(data, times)
         np.testing.assert_array_equal(data_slc, data[1:3])
         np.testing.assert_array_equal(times_slc, times[1:3])
         self.assertEqual(fh.start_time, datetime(1970, 1, 1, 0, 0, 0, 2))
         self.assertEqual(fh.end_time, datetime(1970, 1, 1, 0, 0, 0, 3))
-        self.assertEqual(fh.midnight_scanline, 'midn_line')
-        np.testing.assert_array_equal(fh.missing_scanlines, np.array([1, 2, 3]))
-        self.assertEqual(fh.missing_scanlines.dtype, int)
 
     @mock.patch('satpy.readers.avhrr_l1b_gaclac.GACLACFile._get_qual_flags')
     @mock.patch('satpy.readers.avhrr_l1b_gaclac.GACLACFile._strip_invalid_lat')
@@ -441,39 +471,38 @@ class TestGACLACFile(TestCase):
         """Test slicing."""
         import pygac.utils
         pygac.utils.check_user_scanlines.return_value = 1, 2
-        pygac.utils.slice_channel.return_value = 'sliced', 'miss_lines', 'midn_line'
+        pygac.utils.slice_channel.return_value = 'sliced'
         strip_invalid_lat.return_value = 3, 4
         get_qual_flags.return_value = 'qual_flags'
 
         data = np.zeros((2, 2))
 
         # a) Only start/end line given
-        fh = self._get_fh_mocked(start_line=5, end_line=6, strip_invalid_coords=False,
-                                 midnight_scanline=None, missing_scanlines=None)
-        data_slc, midn_line, miss_lines = fh._slice(data)
+        fh = self._get_fh_mocked(start_line=5, end_line=6, strip_invalid_coords=False)
+        data_slc = fh._slice(data)
         self.assertEqual(data_slc, 'sliced')
-        self.assertEqual(midn_line, 'midn_line')
-        self.assertEqual(miss_lines, 'miss_lines')
         pygac.utils.check_user_scanlines.assert_called_with(
             start_line=5, end_line=6,
             first_valid_lat=None, last_valid_lat=None, along_track=2)
         pygac.utils.slice_channel.assert_called_with(
             data, start_line=1, end_line=2,
-            first_valid_lat=None, last_valid_lat=None,
-            midnight_scanline=None, miss_lines=None, qual_flags='qual_flags')
+            first_valid_lat=None, last_valid_lat=None)
 
         # b) Only strip_invalid_coords=True
-        fh = self._get_fh_mocked(start_line=None, end_line=None, strip_invalid_coords=True,
-                                 midnight_scanline=None, missing_scanlines=None)
+        fh = self._get_fh_mocked(start_line=None, end_line=None, strip_invalid_coords=True)
         fh._slice(data)
         pygac.utils.check_user_scanlines.assert_called_with(
             start_line=0, end_line=0,
             first_valid_lat=3, last_valid_lat=4, along_track=2)
 
         # c) Both
-        fh = self._get_fh_mocked(start_line=5, end_line=6, strip_invalid_coords=True,
-                                 midnight_scanline=None, missing_scanlines=None)
+        fh = self._get_fh_mocked(start_line=5, end_line=6, strip_invalid_coords=True)
         fh._slice(data)
         pygac.utils.check_user_scanlines.assert_called_with(
             start_line=5, end_line=6,
             first_valid_lat=3, last_valid_lat=4, along_track=2)
+
+        # Test slicing with older pygac versions
+        pygac.utils.slice_channel.return_value = ('sliced', 'foo', 'bar')
+        data_slc = fh._slice(data)
+        self.assertEqual(data_slc, 'sliced')
