@@ -227,7 +227,6 @@ class FakeNetCDF4FileHandler3(FakeNetCDF4FileHandler2):
 @pytest.fixture
 def reader_configs():
     """Return reader configs for FCI."""
-
     from satpy.config import config_search_paths
     return config_search_paths(
         os.path.join("readers", "fci_l1c_fdhsi.yaml"))
@@ -296,7 +295,7 @@ class TestFCIL1CFDHSIReaderGoodData(TestFCIL1CFDHSIReader):
 
     def test_load_counts(self, reader_configs):
         """Test loading with counts."""
-        from satpy import DatasetID
+        from satpy.tests.utils import make_dataid
         from satpy.readers import load_reader
 
         # testing two filenames to test correctly combined
@@ -313,8 +312,8 @@ class TestFCIL1CFDHSIReaderGoodData(TestFCIL1CFDHSIReader):
         loadables = reader.select_files_from_pathnames(filenames)
         reader.create_filehandlers(loadables)
         res = reader.load(
-                [DatasetID(name=name, calibration="counts") for name in
-                    self._chans["solar"] + self._chans["terran"]])
+                [make_dataid(name=name, calibration="counts") for name in
+                    self._chans["solar"] + self._chans["terran"]], pad_data=False)
         assert 16 == len(res)
         for ch in self._chans["solar"] + self._chans["terran"]:
             assert res[ch].shape == (200*2, 11136)
@@ -329,7 +328,7 @@ class TestFCIL1CFDHSIReaderGoodData(TestFCIL1CFDHSIReader):
 
     def test_load_radiance(self, reader_configs):
         """Test loading with radiance."""
-        from satpy import DatasetID
+        from satpy.tests.utils import make_dataid
         from satpy.readers import load_reader
 
         filenames = [
@@ -342,8 +341,8 @@ class TestFCIL1CFDHSIReaderGoodData(TestFCIL1CFDHSIReader):
         loadables = reader.select_files_from_pathnames(filenames)
         reader.create_filehandlers(loadables)
         res = reader.load(
-                [DatasetID(name=name, calibration="radiance") for name in
-                    self._chans["solar"] + self._chans["terran"]])
+                [make_dataid(name=name, calibration="radiance") for name in
+                    self._chans["solar"] + self._chans["terran"]], pad_data=False)
         assert 16 == len(res)
         for ch in self._chans["solar"] + self._chans["terran"]:
             assert res[ch].shape == (200, 11136)
@@ -358,7 +357,7 @@ class TestFCIL1CFDHSIReaderGoodData(TestFCIL1CFDHSIReader):
 
     def test_load_reflectance(self, reader_configs):
         """Test loading with reflectance."""
-        from satpy import DatasetID
+        from satpy.tests.utils import make_dataid
         from satpy.readers import load_reader
 
         filenames = [
@@ -371,8 +370,8 @@ class TestFCIL1CFDHSIReaderGoodData(TestFCIL1CFDHSIReader):
         loadables = reader.select_files_from_pathnames(filenames)
         reader.create_filehandlers(loadables)
         res = reader.load(
-                [DatasetID(name=name, calibration="reflectance") for name in
-                    self._chans["solar"]])
+                [make_dataid(name=name, calibration="reflectance") for name in
+                    self._chans["solar"]], pad_data=False)
         assert 8 == len(res)
         for ch in self._chans["solar"]:
             assert res[ch].shape == (200, 11136)
@@ -383,7 +382,7 @@ class TestFCIL1CFDHSIReaderGoodData(TestFCIL1CFDHSIReader):
 
     def test_load_bt(self, reader_configs, caplog):
         """Test loading with bt."""
-        from satpy import DatasetID
+        from satpy.tests.utils import make_dataid
         from satpy.readers import load_reader
         filenames = [
             "W_XX-EUMETSAT-Darmstadt,IMG+SAT,MTI1+FCI-1C-RRAD-FDHSI-FD--"
@@ -396,8 +395,8 @@ class TestFCIL1CFDHSIReaderGoodData(TestFCIL1CFDHSIReader):
         reader.create_filehandlers(loadables)
         with caplog.at_level(logging.WARNING):
             res = reader.load(
-                    [DatasetID(name=name, calibration="brightness_temperature") for
-                        name in self._chans["terran"]])
+                    [make_dataid(name=name, calibration="brightness_temperature") for
+                        name in self._chans["terran"]], pad_data=False)
             assert caplog.text == ""
         for ch in self._chans["terran"]:
             assert res[ch].shape == (200, 11136)
@@ -436,7 +435,7 @@ class TestFCIL1CFDHSIReaderGoodData(TestFCIL1CFDHSIReader):
         reader = load_reader(reader_configs)
         loadables = reader.select_files_from_pathnames(filenames)
         reader.create_filehandlers(loadables)
-        res = reader.load(["ir_123_pixel_quality"])
+        res = reader.load(["ir_123_pixel_quality"], pad_data=False)
         assert res["ir_123_pixel_quality"].attrs["name"] == "ir_123_pixel_quality"
 
     def test_platform_name(self, reader_configs):
@@ -456,12 +455,12 @@ class TestFCIL1CFDHSIReaderGoodData(TestFCIL1CFDHSIReader):
         reader = load_reader(reader_configs)
         loadables = reader.select_files_from_pathnames(filenames)
         reader.create_filehandlers(loadables)
-        res = reader.load(["ir_123"])
+        res = reader.load(["ir_123"], pad_data=False)
         assert res["ir_123"].attrs["platform_name"] == "MTG-I1"
 
-    def test_excs(self, reader_configs, caplog):
+    def test_excs(self, reader_configs):
         """Test that exceptions are raised where expected."""
-        from satpy import DatasetID
+        from satpy.tests.utils import make_dataid
         from satpy.readers import load_reader
 
         filenames = [
@@ -475,15 +474,14 @@ class TestFCIL1CFDHSIReaderGoodData(TestFCIL1CFDHSIReader):
         fhs = reader.create_filehandlers(loadables)
 
         with pytest.raises(ValueError):
-            fhs["fci_l1c_fdhsi"][0].get_dataset(DatasetID(name="invalid"), {})
+            fhs["fci_l1c_fdhsi"][0].get_dataset(make_dataid(name="invalid"), {})
         with pytest.raises(ValueError):
-            fhs["fci_l1c_fdhsi"][0]._get_dataset_quality(DatasetID(name="invalid"),
+            fhs["fci_l1c_fdhsi"][0]._get_dataset_quality(make_dataid(name="invalid"),
                                                          {})
-        with caplog.at_level(logging.ERROR):
+        with pytest.raises(ValueError):
             fhs["fci_l1c_fdhsi"][0].get_dataset(
-                    DatasetID(name="ir_123", calibration="unknown"),
+                    make_dataid(name="ir_123", calibration="unknown"),
                     {"units": "unknown"})
-            assert "unknown calibration key" in caplog.text
 
 
 class TestFCIL1CFDHSIReaderBadData(TestFCIL1CFDHSIReader):
@@ -493,7 +491,7 @@ class TestFCIL1CFDHSIReaderBadData(TestFCIL1CFDHSIReader):
 
     def test_handling_bad_data_ir(self, reader_configs, caplog):
         """Test handling of bad IR data."""
-        from satpy import DatasetID
+        from satpy.tests.utils import make_dataid
         from satpy.readers import load_reader
 
         filenames = [
@@ -506,14 +504,14 @@ class TestFCIL1CFDHSIReaderBadData(TestFCIL1CFDHSIReader):
         loadables = reader.select_files_from_pathnames(filenames)
         reader.create_filehandlers(loadables)
         with caplog.at_level("ERROR"):
-            reader.load([DatasetID(
+            reader.load([make_dataid(
                     name="ir_123",
-                    calibration="brightness_temperature")])
+                    calibration="brightness_temperature")], pad_data=False)
             assert "cannot produce brightness temperature" in caplog.text
 
     def test_handling_bad_data_vis(self, reader_configs, caplog):
         """Test handling of bad VIS data."""
-        from satpy import DatasetID
+        from satpy.tests.utils import make_dataid
         from satpy.readers import load_reader
 
         filenames = [
@@ -526,7 +524,7 @@ class TestFCIL1CFDHSIReaderBadData(TestFCIL1CFDHSIReader):
         loadables = reader.select_files_from_pathnames(filenames)
         reader.create_filehandlers(loadables)
         with caplog.at_level("ERROR"):
-            reader.load([DatasetID(
+            reader.load([make_dataid(
                     name="vis_04",
-                    calibration="reflectance")])
+                    calibration="reflectance")], pad_data=False)
             assert "cannot produce reflectance" in caplog.text
