@@ -54,9 +54,10 @@ ALL_PRESSURE_LEVELS = np.repeat([ALL_PRESSURE_LEVELS], DEFAULT_PRES_FILE_SHAPE[0
 
 
 class FakeNetCDF4FileHandler2(FakeNetCDF4FileHandler):
-    """Swap-in NetCDF4 File Handler"""
+    """Swap-in NetCDF4 File Handler."""
+
     def get_test_content(self, filename, filename_info, filetype_info):
-        """Mimic reader input file content"""
+        """Mimic reader input file content."""
         file_content = {
             '/attr/time_coverage_start': filename_info['start_time'].strftime('%Y-%m-%dT%H:%M:%S.%fZ'),
             '/attr/time_coverage_end': filename_info['end_time'].strftime('%Y-%m-%dT%H:%M:%S.%fZ'),
@@ -149,11 +150,12 @@ class FakeNetCDF4FileHandler2(FakeNetCDF4FileHandler):
 
 
 class TestNUCAPSReader(unittest.TestCase):
-    """Test NUCAPS Reader"""
+    """Test NUCAPS Reader."""
+
     yaml_file = "nucaps.yaml"
 
     def setUp(self):
-        """Wrap NetCDF4 file handler with our own fake handler"""
+        """Wrap NetCDF4 file handler with our own fake handler."""
         from satpy.config import config_search_paths
         from satpy.readers.nucaps import NUCAPSFileHandler
         self.reader_configs = config_search_paths(os.path.join('readers', self.yaml_file))
@@ -163,7 +165,7 @@ class TestNUCAPSReader(unittest.TestCase):
         self.p.is_local = True
 
     def tearDown(self):
-        """Stop wrapping the NetCDF4 file handler"""
+        """Stop wrapping the NetCDF4 file handler."""
         self.p.stop()
 
     def test_init(self):
@@ -173,13 +175,25 @@ class TestNUCAPSReader(unittest.TestCase):
         loadables = r.select_files_from_pathnames([
             'NUCAPS-EDR_v1r0_npp_s201603011158009_e201603011158307_c201603011222270.nc',
         ])
-        self.assertTrue(len(loadables), 1)
+        self.assertEqual(len(loadables), 1)
         r.create_filehandlers(loadables)
         # make sure we have some files
         self.assertTrue(r.file_handlers)
 
+    def test_init_with_kwargs(self):
+        """Test basic init with extra parameters."""
+        from satpy.readers import load_reader
+        r = load_reader(self.reader_configs, mask_surface=False)
+        loadables = r.select_files_from_pathnames([
+            'NUCAPS-EDR_v1r0_npp_s201603011158009_e201603011158307_c201603011222270.nc',
+        ])
+        self.assertEqual(len(loadables), 1)
+        r.create_filehandlers(loadables, fh_kwargs={'mask_surface': False})
+        # make sure we have some files
+        self.assertTrue(r.file_handlers)
+
     def test_load_nonpressure_based(self):
-        """Test loading all channels that aren't based on pressure"""
+        """Test loading all channels that aren't based on pressure."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -201,7 +215,7 @@ class TestNUCAPSReader(unittest.TestCase):
             self.assertEqual(v.attrs['sensor'], ['CrIS', 'ATMS', 'VIIRS'])
 
     def test_load_pressure_based(self):
-        """Test loading all channels based on pressure"""
+        """Test loading all channels based on pressure."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -234,7 +248,7 @@ class TestNUCAPSReader(unittest.TestCase):
             self.assertEqual(v.ndim, 2)
 
     def test_load_individual_pressure_levels_true(self):
-        """Test loading Temperature with individual pressure datasets"""
+        """Test loading Temperature with individual pressure datasets."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -247,7 +261,7 @@ class TestNUCAPSReader(unittest.TestCase):
             self.assertEqual(v.ndim, 1)
 
     def test_load_individual_pressure_levels_min_max(self):
-        """Test loading individual Temperature with min/max level specified"""
+        """Test loading individual Temperature with min/max level specified."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -260,7 +274,7 @@ class TestNUCAPSReader(unittest.TestCase):
             self.assertEqual(v.ndim, 1)
 
     def test_load_individual_pressure_levels_single(self):
-        """Test loading individual Temperature with specific levels"""
+        """Test loading individual Temperature with specific levels."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -273,7 +287,7 @@ class TestNUCAPSReader(unittest.TestCase):
             self.assertEqual(v.ndim, 1)
 
     def test_load_pressure_levels_true(self):
-        """Test loading Temperature with all pressure levels"""
+        """Test loading Temperature with all pressure levels."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -287,7 +301,7 @@ class TestNUCAPSReader(unittest.TestCase):
             self.assertTupleEqual(v.shape, DEFAULT_PRES_FILE_SHAPE)
 
     def test_load_pressure_levels_min_max(self):
-        """Test loading Temperature with min/max level specified"""
+        """Test loading Temperature with min/max level specified."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -302,7 +316,7 @@ class TestNUCAPSReader(unittest.TestCase):
                                   (DEFAULT_PRES_FILE_SHAPE[0], 6))
 
     def test_load_pressure_levels_single(self):
-        """Test loading a specific Temperature level"""
+        """Test loading a specific Temperature level."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -317,7 +331,7 @@ class TestNUCAPSReader(unittest.TestCase):
                                   (DEFAULT_PRES_FILE_SHAPE[0], 1))
 
     def test_load_pressure_levels_single_and_pressure_levels(self):
-        """Test loading a specific Temperature level and pressure levels"""
+        """Test loading a specific Temperature level and pressure levels."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -335,11 +349,12 @@ class TestNUCAPSReader(unittest.TestCase):
 
 
 class TestNUCAPSScienceEDRReader(unittest.TestCase):
-    """Test NUCAPS Science EDR Reader"""
+    """Test NUCAPS Science EDR Reader."""
+
     yaml_file = "nucaps.yaml"
 
     def setUp(self):
-        """Wrap NetCDF4 file handler with our own fake handler"""
+        """Wrap NetCDF4 file handler with our own fake handler."""
         from satpy.config import config_search_paths
         from satpy.readers.nucaps import NUCAPSFileHandler
         self.reader_configs = config_search_paths(os.path.join('readers', self.yaml_file))
@@ -349,7 +364,7 @@ class TestNUCAPSScienceEDRReader(unittest.TestCase):
         self.p.is_local = True
 
     def tearDown(self):
-        """Stop wrapping the NetCDF4 file handler"""
+        """Stop wrapping the NetCDF4 file handler."""
         self.p.stop()
 
     def test_init(self):
@@ -359,13 +374,13 @@ class TestNUCAPSScienceEDRReader(unittest.TestCase):
         loadables = r.select_files_from_pathnames([
             'NUCAPS-sciEDR_am_npp_s20190703223319_e20190703223349_STC_fsr.nc',
         ])
-        self.assertTrue(len(loadables), 1)
+        self.assertEqual(len(loadables), 1)
         r.create_filehandlers(loadables)
         # make sure we have some files
         self.assertTrue(r.file_handlers)
 
     def test_load_nonpressure_based(self):
-        """Test loading all channels that aren't based on pressure"""
+        """Test loading all channels that aren't based on pressure."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -384,7 +399,7 @@ class TestNUCAPSScienceEDRReader(unittest.TestCase):
             self.assertEqual(v.attrs['sensor'], ['CrIS', 'ATMS', 'VIIRS'])
 
     def test_load_pressure_based(self):
-        """Test loading all channels based on pressure"""
+        """Test loading all channels based on pressure."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -414,7 +429,7 @@ class TestNUCAPSScienceEDRReader(unittest.TestCase):
             self.assertEqual(v.ndim, 2)
 
     def test_load_individual_pressure_levels_true(self):
-        """Test loading Temperature with individual pressure datasets"""
+        """Test loading Temperature with individual pressure datasets."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -427,7 +442,7 @@ class TestNUCAPSScienceEDRReader(unittest.TestCase):
             self.assertEqual(v.ndim, 1)
 
     def test_load_individual_pressure_levels_min_max(self):
-        """Test loading individual Temperature with min/max level specified"""
+        """Test loading individual Temperature with min/max level specified."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -440,7 +455,7 @@ class TestNUCAPSScienceEDRReader(unittest.TestCase):
             self.assertEqual(v.ndim, 1)
 
     def test_load_individual_pressure_levels_single(self):
-        """Test loading individual Temperature with specific levels"""
+        """Test loading individual Temperature with specific levels."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -453,7 +468,7 @@ class TestNUCAPSScienceEDRReader(unittest.TestCase):
             self.assertEqual(v.ndim, 1)
 
     def test_load_pressure_levels_true(self):
-        """Test loading Temperature with all pressure levels"""
+        """Test loading Temperature with all pressure levels."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -467,7 +482,7 @@ class TestNUCAPSScienceEDRReader(unittest.TestCase):
             self.assertTupleEqual(v.shape, DEFAULT_PRES_FILE_SHAPE)
 
     def test_load_pressure_levels_min_max(self):
-        """Test loading Temperature with min/max level specified"""
+        """Test loading Temperature with min/max level specified."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -482,7 +497,7 @@ class TestNUCAPSScienceEDRReader(unittest.TestCase):
                                   (DEFAULT_PRES_FILE_SHAPE[0], 6))
 
     def test_load_pressure_levels_single(self):
-        """Test loading a specific Temperature level"""
+        """Test loading a specific Temperature level."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
@@ -497,7 +512,7 @@ class TestNUCAPSScienceEDRReader(unittest.TestCase):
                                   (DEFAULT_PRES_FILE_SHAPE[0], 1))
 
     def test_load_pressure_levels_single_and_pressure_levels(self):
-        """Test loading a specific Temperature level and pressure levels"""
+        """Test loading a specific Temperature level and pressure levels."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
