@@ -47,31 +47,31 @@ class TestNcNWCSAF(unittest.TestCase):
         """Test that the correct sensor name is being set"""
 
         self.scn.set_platform_and_sensor(platform_name='Metop-B')
-        self.assertTrue(self.scn.sensor, set(['avhrr-3']))
-        self.assertTrue(self.scn.sensor_names, set(['avhrr-3']))
+        self.assertEqual(self.scn.sensor, set(['avhrr-3']))
+        self.assertEqual(self.scn.sensor_names, set(['avhrr-3']))
 
         self.scn.set_platform_and_sensor(platform_name='NOAA-20')
-        self.assertTrue(self.scn.sensor, set(['viirs']))
-        self.assertTrue(self.scn.sensor_names, set(['viirs']))
+        self.assertEqual(self.scn.sensor, set(['viirs']))
+        self.assertEqual(self.scn.sensor_names, set(['viirs']))
 
         self.scn.set_platform_and_sensor(platform_name='Himawari-8')
-        self.assertTrue(self.scn.sensor, set(['ahi']))
-        self.assertTrue(self.scn.sensor_names, set(['ahi']))
+        self.assertEqual(self.scn.sensor, set(['ahi']))
+        self.assertEqual(self.scn.sensor_names, set(['ahi']))
 
         self.scn.set_platform_and_sensor(sat_id='GOES16')
-        self.assertTrue(self.scn.sensor, set(['abi']))
-        self.assertTrue(self.scn.sensor_names, set(['abi']))
+        self.assertEqual(self.scn.sensor, set(['abi']))
+        self.assertEqual(self.scn.sensor_names, set(['abi']))
 
         self.scn.set_platform_and_sensor(platform_name='GOES-17')
-        self.assertTrue(self.scn.sensor, set(['abi']))
-        self.assertTrue(self.scn.sensor_names, set(['abi']))
+        self.assertEqual(self.scn.sensor, set(['abi']))
+        self.assertEqual(self.scn.sensor_names, set(['abi']))
 
         self.scn.set_platform_and_sensor(sat_id='MSG4')
-        self.assertTrue(self.scn.sensor, set(['seviri']))
+        self.assertEqual(self.scn.sensor, set(['seviri']))
 
         self.scn.set_platform_and_sensor(platform_name='Meteosat-11')
-        self.assertTrue(self.scn.sensor, set(['seviri']))
-        self.assertTrue(self.scn.sensor_names, set(['seviri']))
+        self.assertEqual(self.scn.sensor, set(['seviri']))
+        self.assertEqual(self.scn.sensor_names, set(['seviri']))
 
     def test_get_projection(self):
         """Test generation of the navigation info."""
