@@ -17,6 +17,7 @@
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """Tests for compositors in composites/__init__.py."""
 
+import os
 import unittest
 from datetime import datetime
 from unittest import mock
@@ -501,15 +502,15 @@ class TestInlineComposites(unittest.TestCase):
         comps = cl_.compositors
         # Check that "fog" product has all its prerequisites defined
         keys = comps['visir'].keys()
-        fog = [comps['visir'][dsid] for dsid in keys if "fog" == dsid.name][0]
-        self.assertEqual(fog.attrs['prerequisites'][0], '_fog_dep_0')
-        self.assertEqual(fog.attrs['prerequisites'][1], '_fog_dep_1')
+        fog = [comps['visir'][dsid] for dsid in keys if "fog" == dsid['name']][0]
+        self.assertEqual(fog.attrs['prerequisites'][0]['name'], '_fog_dep_0')
+        self.assertEqual(fog.attrs['prerequisites'][1]['name'], '_fog_dep_1')
         self.assertEqual(fog.attrs['prerequisites'][2], 10.8)
 
         # Check that the sub-composite dependencies use wavelengths
         # (numeric values)
         keys = comps['visir'].keys()
-        fog_dep_ids = [dsid for dsid in keys if "fog_dep" in dsid.name]
+        fog_dep_ids = [dsid for dsid in keys if "fog_dep" in dsid['name']]
         self.assertEqual(comps['visir'][fog_dep_ids[0]].attrs['prerequisites'],
                          [12.0, 10.8])
         self.assertEqual(comps['visir'][fog_dep_ids[1]].attrs['prerequisites'],
@@ -521,7 +522,7 @@ class TestInlineComposites(unittest.TestCase):
         cl_.load_sensor_composites('seviri')
         comps = cl_.compositors
         keys = comps['seviri'].keys()
-        fog_dep_ids = [dsid for dsid in keys if "fog_dep" in dsid.name]
+        fog_dep_ids = [dsid for dsid in keys if "fog_dep" in dsid['name']]
         self.assertEqual(comps['seviri'][fog_dep_ids[0]].attrs['prerequisites'],
                          ['IR_120', 'IR_108'])
         self.assertEqual(comps['seviri'][fog_dep_ids[1]].attrs['prerequisites'],
@@ -531,81 +532,139 @@ class TestInlineComposites(unittest.TestCase):
 class TestNIRReflectance(unittest.TestCase):
     """Test NIR reflectance compositor."""
 
+    def setUp(self):
+        """Set up the test case for the NIRReflectance compositor."""
+        self.get_lonlats = mock.MagicMock()
+        self.lons, self.lats = 1, 2
+        self.get_lonlats.return_value = (self.lons, self.lats)
+        area = mock.MagicMock(get_lonlats=self.get_lonlats)
+
+        self.start_time = 1
+        self.metadata = {'platform_name': 'Meteosat-11',
+                         'sensor': 'seviri',
+                         'name': 'IR_039',
+                         'area': area,
+                         'start_time': self.start_time}
+
+        nir_arr = np.random.random((2, 2))
+        self.nir = xr.DataArray(da.from_array(nir_arr), dims=['y', 'x'])
+        self.nir.attrs.update(self.metadata)
+
+        ir_arr = 100 * np.random.random((2, 2))
+        self.ir_ = xr.DataArray(da.from_array(ir_arr), dims=['y', 'x'])
+        self.ir_.attrs['area'] = area
+
+        self.sunz_arr = 100 * np.random.random((2, 2))
+        self.sunz = xr.DataArray(da.from_array(self.sunz_arr), dims=['y', 'x'])
+        self.sunz.attrs['standard_name'] = 'solar_zenith_angle'
+        self.sunz.attrs['area'] = area
+        self.da_sunz = da.from_array(self.sunz_arr)
+
+        refl_arr = np.random.random((2, 2))
+        self.refl = da.from_array(refl_arr)
+        self.refl_with_co2 = da.from_array(np.random.random((2, 2)))
+        self.refl_from_tbs = mock.MagicMock()
+        self.refl_from_tbs.side_effect = self.fake_refl_from_tbs
+
+    def fake_refl_from_tbs(self, sun_zenith, da_nir, da_tb11, tb_ir_co2=None):
+        """Fake refl_from_tbs."""
+        del sun_zenith, da_nir, da_tb11
+        if tb_ir_co2 is not None:
+            return self.refl_with_co2
+        else:
+            return self.refl
+
     @mock.patch('satpy.composites.sun_zenith_angle')
     @mock.patch('satpy.composites.NIRReflectance.apply_modifier_info')
     @mock.patch('satpy.composites.Calculator')
-    def test_compositor(self, calculator, apply_modifier_info, sza):
-        """Test NIR reflectance compositor."""
-        import numpy as np
-        import xarray as xr
-        import dask.array as da
-        refl_arr = np.random.random((2, 2))
-        refl = da.from_array(refl_arr)
-        refl_from_tbs = mock.MagicMock()
-        refl_from_tbs.return_value = refl
+    def test_provide_sunz_no_co2(self, calculator, apply_modifier_info, sza):
+        """Test NIR reflectance compositor provided only sunz."""
         calculator.return_value = mock.MagicMock(
-            reflectance_from_tbs=refl_from_tbs)
-
+            reflectance_from_tbs=self.refl_from_tbs)
+        sza.return_value = self.da_sunz
         from satpy.composites import NIRReflectance
 
-        nir_arr = np.random.random((2, 2))
-        nir = xr.DataArray(da.from_array(nir_arr), dims=['y', 'x'])
-        platform = 'Meteosat-11'
-        sensor = 'seviri'
-        chan_name = 'IR_039'
-        nir.attrs['platform_name'] = platform
-        nir.attrs['sensor'] = sensor
-        nir.attrs['name'] = chan_name
-        get_lonlats = mock.MagicMock()
-        lons, lats = 1, 2
-        get_lonlats.return_value = (lons, lats)
-        area = mock.MagicMock(get_lonlats=get_lonlats)
-        nir.attrs['area'] = area
-        start_time = 1
-        nir.attrs['start_time'] = start_time
-        ir_arr = 100 * np.random.random((2, 2))
-        ir_ = xr.DataArray(da.from_array(ir_arr), dims=['y', 'x'])
-        ir_.attrs['area'] = area
-        sunz_arr = 100 * np.random.random((2, 2))
-        sunz = xr.DataArray(da.from_array(sunz_arr), dims=['y', 'x'])
-        sunz.attrs['standard_name'] = 'solar_zenith_angle'
-        sunz.attrs['area'] = area
-        sunz2 = da.from_array(sunz_arr)
-        sza.return_value = sunz2
-
         comp = NIRReflectance(name='test')
         info = {'modifiers': None}
-        res = comp([nir, ir_], optional_datasets=[sunz], **info)
-        self.assertEqual(res.attrs['units'], '%')
-        self.assertEqual(res.attrs['platform_name'], platform)
-        self.assertEqual(res.attrs['sensor'], sensor)
-        self.assertEqual(res.attrs['name'], chan_name)
-        self.assertEqual(res.attrs['sunz_threshold'], None)
-        calculator.assert_called()
-        calculator.assert_called_with('Meteosat-11', 'seviri', 'IR_039', sunz_threshold=None)
-        self.assertTrue(apply_modifier_info.call_args[0][0] is nir)
-        self.assertTrue(comp._refl3x is calculator.return_value)
-        refl_from_tbs.reset_mock()
+        res = comp([self.nir, self.ir_], optional_datasets=[self.sunz], **info)
 
-        res = comp([nir, ir_], optional_datasets=[], **info)
-        get_lonlats.assert_called()
-        sza.assert_called_with(start_time, lons, lats)
-        refl_from_tbs.assert_called_with(sunz2, nir.data, ir_.data, tb_ir_co2=None)
-        refl_from_tbs.reset_mock()
+        assert self.metadata.items() <= res.attrs.items()
+        assert res.attrs['units'] == '%'
+        assert res.attrs['sun_zenith_threshold'] is not None
+        assert np.allclose(res.data, self.refl * 100).compute()
 
+    @mock.patch('satpy.composites.sun_zenith_angle')
+    @mock.patch('satpy.composites.NIRReflectance.apply_modifier_info')
+    @mock.patch('satpy.composites.Calculator')
+    def test_no_sunz_no_co2(self, calculator, apply_modifier_info, sza):
+        """Test NIR reflectance compositor with minimal parameters."""
+        calculator.return_value = mock.MagicMock(
+            reflectance_from_tbs=self.refl_from_tbs)
+        sza.return_value = self.da_sunz
+        from satpy.composites import NIRReflectance
+
+        comp = NIRReflectance(name='test')
+        info = {'modifiers': None}
+        res = comp([self.nir, self.ir_], optional_datasets=[], **info)
+
+        self.get_lonlats.assert_called()
+        sza.assert_called_with(self.start_time, self.lons, self.lats)
+        self.refl_from_tbs.assert_called_with(self.da_sunz, self.nir.data, self.ir_.data, tb_ir_co2=None)
+        assert np.allclose(res.data, self.refl * 100).compute()
+
+    @mock.patch('satpy.composites.sun_zenith_angle')
+    @mock.patch('satpy.composites.NIRReflectance.apply_modifier_info')
+    @mock.patch('satpy.composites.Calculator')
+    def test_no_sunz_with_co2(self, calculator, apply_modifier_info, sza):
+        """Test NIR reflectance compositor provided extra co2 info."""
+        calculator.return_value = mock.MagicMock(
+            reflectance_from_tbs=self.refl_from_tbs)
+        from satpy.composites import NIRReflectance
+        sza.return_value = self.da_sunz
+
+        comp = NIRReflectance(name='test')
+        info = {'modifiers': None}
         co2_arr = np.random.random((2, 2))
         co2 = xr.DataArray(da.from_array(co2_arr), dims=['y', 'x'])
         co2.attrs['wavelength'] = [12.0, 13.0, 14.0]
         co2.attrs['units'] = 'K'
-        res = comp([nir, ir_], optional_datasets=[co2], **info)
-        refl_from_tbs.assert_called_with(sunz2, nir.data, ir_.data, tb_ir_co2=co2.data)
+        res = comp([self.nir, self.ir_], optional_datasets=[co2], **info)
+
+        self.refl_from_tbs.assert_called_with(self.da_sunz, self.nir.data, self.ir_.data, tb_ir_co2=co2.data)
+        assert np.allclose(res.data, self.refl_with_co2 * 100).compute()
+
+    @mock.patch('satpy.composites.sun_zenith_angle')
+    @mock.patch('satpy.composites.NIRReflectance.apply_modifier_info')
+    @mock.patch('satpy.composites.Calculator')
+    def test_provide_sunz_and_threshold(self, calculator, apply_modifier_info, sza):
+        """Test NIR reflectance compositor provided sunz and a sunz threshold."""
+        calculator.return_value = mock.MagicMock(
+            reflectance_from_tbs=self.refl_from_tbs)
+        from satpy.composites import NIRReflectance
+        sza.return_value = self.da_sunz
 
         comp = NIRReflectance(name='test', sunz_threshold=84.0)
         info = {'modifiers': None}
-        res = comp([nir, ir_], optional_datasets=[sunz], **info)
-        self.assertEqual(res.attrs['sunz_threshold'], 84.0)
+        res = comp([self.nir, self.ir_], optional_datasets=[self.sunz], **info)
+
+        self.assertEqual(res.attrs['sun_zenith_threshold'], 84.0)
         calculator.assert_called_with('Meteosat-11', 'seviri', 'IR_039', sunz_threshold=84.0)
 
+    @mock.patch('satpy.composites.sun_zenith_angle')
+    @mock.patch('satpy.composites.NIRReflectance.apply_modifier_info')
+    @mock.patch('satpy.composites.Calculator')
+    def test_sunz_threshold_default_value_is_not_none(self, calculator, apply_modifier_info, sza):
+        """Check that sun_zenith_threshold is not None."""
+        from satpy.composites import NIRReflectance
+
+        comp = NIRReflectance(name='test', sunz_threshold=None)
+        info = {'modifiers': None}
+        calculator.return_value = mock.MagicMock(
+            reflectance_from_tbs=self.refl_from_tbs)
+        comp([self.nir, self.ir_], optional_datasets=[self.sunz], **info)
+
+        assert comp.sun_zenith_threshold is not None
+
 
 class TestNIREmissivePartFromReflectance(unittest.TestCase):
     """Test the NIR Emissive part from reflectance compositor."""
@@ -664,7 +723,7 @@ class TestNIREmissivePartFromReflectance(unittest.TestCase):
         sza.return_value = sunz2
 
         res = comp([nir, ir_], optional_datasets=[sunz], **info)
-        self.assertEqual(res.attrs['sunz_threshold'], 86.0)
+        self.assertEqual(res.attrs['sun_zenith_threshold'], 86.0)
         self.assertEqual(res.attrs['units'], 'K')
         self.assertEqual(res.attrs['platform_name'], platform)
         self.assertEqual(res.attrs['sensor'], sensor)
@@ -675,21 +734,26 @@ class TestNIREmissivePartFromReflectance(unittest.TestCase):
 class TestColormapCompositor(unittest.TestCase):
     """Test the ColormapCompositor."""
 
-    def test_build_colormap(self):
-        """Test colormap building."""
+    def setUp(self):
+        """Set up the test case."""
         from satpy.composites import ColormapCompositor
-        cmap_comp = ColormapCompositor('test_cmap_compositor')
-        palette = np.array([[0, 0, 0], [127, 127, 127], [255, 255, 255]])
-        cmap, sqpal = cmap_comp.build_colormap(palette, np.uint8, {})
-        self.assertTrue(np.allclose(cmap.values, [0, 1]))
-        self.assertTrue(np.allclose(sqpal, palette / 255.0))
+        self.colormap_compositor = ColormapCompositor('test_cmap_compositor')
 
+    def test_build_colormap_with_int_data_and_without_meanings(self):
+        """Test colormap building."""
+        palette = np.array([[0, 0, 0], [127, 127, 127], [255, 255, 255]])
+        colormap, squeezed_palette = self.colormap_compositor.build_colormap(palette, np.uint8, {})
+        self.assertTrue(np.allclose(colormap.values, [0, 1]))
+        self.assertTrue(np.allclose(squeezed_palette, palette / 255.0))
+
+    def test_build_colormap_with_int_data_and_with_meanings(self):
+        """Test colormap building."""
         palette = xr.DataArray(np.array([[0, 0, 0], [127, 127, 127], [255, 255, 255]]),
                                dims=['value', 'band'])
         palette.attrs['palette_meanings'] = [2, 3, 4]
-        cmap, sqpal = cmap_comp.build_colormap(palette, np.uint8, {})
-        self.assertTrue(np.allclose(cmap.values, [2, 3, 4]))
-        self.assertTrue(np.allclose(sqpal, palette / 255.0))
+        colormap, squeezed_palette = self.colormap_compositor.build_colormap(palette, np.uint8, {})
+        self.assertTrue(np.allclose(colormap.values, [2, 3, 4]))
+        self.assertTrue(np.allclose(squeezed_palette, palette / 255.0))
 
 
 class TestPaletteCompositor(unittest.TestCase):
@@ -703,7 +767,7 @@ class TestPaletteCompositor(unittest.TestCase):
                                dims=['value', 'band'])
         palette.attrs['palette_meanings'] = [2, 3, 4]
 
-        data = xr.DataArray(np.array([[4, 3, 2], [2, 3, 4]], dtype=np.uint8), dims=['y', 'x'])
+        data = xr.DataArray(da.from_array(np.array([[4, 3, 2], [2, 3, 4]], dtype=np.uint8)), dims=['y', 'x'])
         res = cmap_comp([data, palette])
         exp = np.array([[[1., 0.498039, 0.],
                          [0., 0.498039, 1.]],
@@ -714,28 +778,99 @@ class TestPaletteCompositor(unittest.TestCase):
         self.assertTrue(np.allclose(res, exp))
 
 
-class TestCloudTopHeightCompositor(unittest.TestCase):
-    """Test the CloudTopHeightCompositor."""
+class TestColorizeCompositor(unittest.TestCase):
+    """Test the ColorizeCompositor."""
 
-    def test_call(self):
-        """Test the CloudTopHeight composite generation."""
-        from satpy.composites.cloud_products import CloudTopHeightCompositor
-        cmap_comp = CloudTopHeightCompositor('test_cmap_compositor')
+    def test_colorize_no_fill(self):
+        """Test colorizing."""
+        from satpy.composites import ColorizeCompositor
+        colormap_composite = ColorizeCompositor('test_color_compositor')
         palette = xr.DataArray(np.array([[0, 0, 0], [127, 127, 127], [255, 255, 255]]),
                                dims=['value', 'band'])
         palette.attrs['palette_meanings'] = [2, 3, 4]
+
+        data = xr.DataArray(np.array([[4, 3, 2],
+                                      [2, 3, 4]],
+                                     dtype=np.uint8),
+                            dims=['y', 'x'])
+        res = colormap_composite([data, palette])
+        exp = np.array([[[1., 0.498039, 0.],
+                         [0., 0.498039, 1.]],
+                        [[1., 0.498039, 0.],
+                         [0., 0.498039, 1.]],
+                        [[1., 0.498039, 0.],
+                         [0., 0.498039, 1.]]])
+        self.assertTrue(np.allclose(res, exp, atol=1e-4))
+
+    def test_colorize_with_interpolation(self):
+        """Test colorizing with interpolation."""
+        from satpy.composites import ColorizeCompositor
+        colormap_composite = ColorizeCompositor('test_color_compositor')
+        palette = xr.DataArray(np.array([[0, 0, 0], [127, 127, 127], [255, 255, 255]]),
+                               dims=['value', 'band'])
+        palette.attrs['palette_meanings'] = [2, 3, 4]
+
+        data = xr.DataArray(da.from_array(np.array([[4, 3, 2.5],
+                                                    [2, 3.2, 4]])),
+                            dims=['y', 'x'],
+                            attrs={'valid_range': np.array([2, 4])})
+        res = colormap_composite([data, palette])
+        exp = np.array([[[1.0000149, 0.49804664, 0.24907766],
+                         [0., 0.59844028, 1.0000149]],
+                        [[1.00005405, 0.49806613, 0.24902255],
+                         [0., 0.59846373, 1.00005405]],
+                        [[1.00001585, 0.49804711, 0.24896771],
+                         [0., 0.59844073, 1.00001585]]])
+        self.assertTrue(np.allclose(res, exp, atol=1e-4))
+
+
+class TestCloudTopHeightCompositor(unittest.TestCase):
+    """Test the CloudTopHeightCompositor."""
+
+    def setUp(self):
+        """Set up the test case."""
+        from satpy.composites.cloud_products import CloudTopHeightCompositor
+        self.colormap_composite = CloudTopHeightCompositor('test_cmap_compositor')
+        self.palette = xr.DataArray(np.array([[0, 0, 0], [127, 127, 127], [255, 255, 255]]),
+                                    dims=['value', 'band'])
+        self.palette.attrs['palette_meanings'] = [2, 3, 4]
+
+        self.exp = np.array([[[0., 0.498, 0.],
+                              [0., 0.498, np.nan]],
+                             [[0., 0.498, 0.],
+                              [0., 0.498, np.nan]],
+                             [[0., 0.498, 0.],
+                              [0., 0.498, np.nan]]])
+
+    def test_call_numpy_with_invalid_value_in_status(self):
+        """Test the CloudTopHeight composite generation."""
         status = xr.DataArray(np.array([[1, 0, 1], [1, 0, 65535]]), dims=['y', 'x'],
                               attrs={'_FillValue': 65535})
         data = xr.DataArray(np.array([[4, 3, 2], [2, 3, 4]], dtype=np.uint8),
                             dims=['y', 'x'])
-        res = cmap_comp([data, palette, status])
-        exp = np.array([[[0., 0.49803922, 0.],
-                         [0., 0.49803922, np.nan]],
-                        [[0., 0.49803922, 0.],
-                         [0., 0.49803922, np.nan]],
-                        [[0., 0.49803922, 0.],
-                         [0., 0.49803922, np.nan]]])
-        np.testing.assert_allclose(res, exp)
+        res = self.colormap_composite([data, self.palette, status])
+
+        np.testing.assert_allclose(res, self.exp, atol=1e-4)
+
+    def test_call_dask_with_invalid_value_in_status(self):
+        """Test the CloudTopHeight composite generation."""
+        status = xr.DataArray(da.from_array(np.array([[1, 0, 1], [1, 0, 65535]])), dims=['y', 'x'],
+                              attrs={'_FillValue': 65535})
+        data = xr.DataArray(da.from_array(np.array([[4, 3, 2], [2, 3, 4]], dtype=np.uint8)),
+                            dims=['y', 'x'])
+        res = self.colormap_composite([data, self.palette, status])
+
+        np.testing.assert_allclose(res, self.exp, atol=1e-4)
+
+    def test_call_dask_with_invalid_value_in_data(self):
+        """Test the CloudTopHeight composite generation."""
+        status = xr.DataArray(da.from_array(np.array([[1, 0, 1], [1, 0, 1]])), dims=['y', 'x'],
+                              attrs={'_FillValue': 65535})
+        data = xr.DataArray(da.from_array(np.array([[4, 3, 2], [2, 3, 99]], dtype=np.uint8)),
+                            dims=['y', 'x'],
+                            attrs={'_FillValue': 99})
+        res = self.colormap_composite([data, self.palette, status])
+        np.testing.assert_allclose(res, self.exp, atol=1e-4)
 
 
 class TestPrecipCloudsCompositor(unittest.TestCase):
@@ -744,7 +879,7 @@ class TestPrecipCloudsCompositor(unittest.TestCase):
     def test_call(self):
         """Test the precip composite generation."""
         from satpy.composites.cloud_products import PrecipCloudsRGB
-        cmap_comp = PrecipCloudsRGB('test_precip_compositor')
+        colormap_compositor = PrecipCloudsRGB('test_precip_compositor')
 
         data_light = xr.DataArray(np.array([[80, 70, 60, 0], [20, 30, 40, 255]], dtype=np.uint8),
                                   dims=['y', 'x'], attrs={'_FillValue': 255})
@@ -754,7 +889,7 @@ class TestPrecipCloudsCompositor(unittest.TestCase):
                                     dims=['y', 'x'], attrs={'_FillValue': 255})
         data_flags = xr.DataArray(np.array([[0, 0, 4, 0], [0, 0, 0, 0]], dtype=np.uint8),
                                   dims=['y', 'x'])
-        res = cmap_comp([data_light, data_moderate, data_intense, data_flags])
+        res = colormap_compositor([data_light, data_moderate, data_intense, data_flags])
 
         exp = np.array([[[0.24313725, 0.18235294, 0.12156863, np.nan],
                          [0.12156863, 0.18235294, 0.24313725, np.nan]],
@@ -936,7 +1071,7 @@ class TestAddBands(unittest.TestCase):
                                  coords={'bands': ['R', 'G', 'B']})
         res = add_bands(data, new_bands)
         res_bands = ['R', 'G', 'B']
-        self.assertEqual(res.mode, ''.join(res_bands))
+        self.assertEqual(res.attrs['mode'], ''.join(res_bands))
         np.testing.assert_array_equal(res.bands, res_bands)
         np.testing.assert_array_equal(res.coords['bands'], res_bands)
 
@@ -947,7 +1082,7 @@ class TestAddBands(unittest.TestCase):
                                  coords={'bands': ['R', 'G', 'B', 'A']})
         res = add_bands(data, new_bands)
         res_bands = ['R', 'G', 'B', 'A']
-        self.assertEqual(res.mode, ''.join(res_bands))
+        self.assertEqual(res.attrs['mode'], ''.join(res_bands))
         np.testing.assert_array_equal(res.bands, res_bands)
         np.testing.assert_array_equal(res.coords['bands'], res_bands)
 
@@ -958,7 +1093,7 @@ class TestAddBands(unittest.TestCase):
                                  coords={'bands': ['R', 'G', 'B']})
         res = add_bands(data, new_bands)
         res_bands = ['R', 'G', 'B', 'A']
-        self.assertEqual(res.mode, ''.join(res_bands))
+        self.assertEqual(res.attrs['mode'], ''.join(res_bands))
         np.testing.assert_array_equal(res.bands, res_bands)
         np.testing.assert_array_equal(res.coords['bands'], res_bands)
 
@@ -970,7 +1105,7 @@ class TestAddBands(unittest.TestCase):
                                  coords={'bands': ['R', 'G', 'B', 'A']})
         res = add_bands(data, new_bands)
         res_bands = ['R', 'G', 'B', 'A']
-        self.assertEqual(res.mode, ''.join(res_bands))
+        self.assertEqual(res.attrs['mode'], ''.join(res_bands))
         np.testing.assert_array_equal(res.bands, res_bands)
         np.testing.assert_array_equal(res.coords['bands'], res_bands)
 
@@ -1034,6 +1169,11 @@ class TestStaticImageCompositor(unittest.TestCase):
         res = comp()
         self.assertEqual(res.attrs['area'].area_id, 'euro4')
 
+        # Filename contains environment variable
+        os.environ["TEST_IMAGE_PATH"] = "/path/to/image"
+        comp = StaticImageCompositor("name", filename="${TEST_IMAGE_PATH}/foo.tif", area='euro4')
+        self.assertEqual(comp.filename, "/path/to/image/foo.tif")
+
 
 def _enhance2dataset(dataset):
     """Mock the enhance2dataset to return the original data."""
@@ -1460,6 +1600,7 @@ class TestNaturalEnhCompositor(unittest.TestCase):
 
         def temp_func(*args):
             return args[0]
+
         match_data_arrays.side_effect = temp_func
         comp = NaturalEnh("foo", ch16_w=self.ch16_w, ch08_w=self.ch08_w,
                           ch06_w=self.ch06_w)
