@@ -18,16 +18,47 @@
 """Unit tests for multiscene.py."""
 
 import os
-import tempfile
 import shutil
-from datetime import datetime
+import tempfile
 import unittest
+from datetime import datetime
 from unittest import mock
 
+from satpy.dataset.dataid import DataID, ModifierTuple, WavelengthRange
+
 DEFAULT_SHAPE = (5, 10)
 
+local_id_keys_config = {'name': {
+    'required': True,
+},
+    'wavelength': {
+    'type': WavelengthRange,
+},
+    'resolution': None,
+    'calibration': {
+    'enum': [
+        'reflectance',
+        'brightness_temperature',
+        'radiance',
+        'counts'
+    ]
+},
+    'polarization': None,
+    'level': None,
+    'modifiers': {
+    'required': True,
+    'default': ModifierTuple(),
+    'type': ModifierTuple,
+},
+}
 
-def _fake_get_enhanced_image(img):
+
+def make_dataid(**items):
+    """Make a data id."""
+    return DataID(local_id_keys_config, **items)
+
+
+def _fake_get_enhanced_image(img, enhance=None, overlay=None, decorate=None):
     from trollimage.xrimage import XRImage
     return XRImage(img)
 
@@ -61,7 +92,7 @@ def _create_test_dataset(name, shape=DEFAULT_SHAPE, area=None):
 
     return xr.DataArray(
         da.zeros(shape, dtype=np.float32, chunks=shape), dims=('y', 'x'),
-        attrs={'name': name, 'area': area})
+        attrs={'name': name, 'area': area, '_satpy_id_keys': local_id_keys_config})
 
 
 def _create_test_scenes(num_scenes=2, shape=DEFAULT_SHAPE, area=None):
@@ -94,14 +125,14 @@ class TestMultiScene(unittest.TestCase):
 
     def test_properties(self):
         """Test basic properties/attributes of the MultiScene."""
-        from satpy import MultiScene, DatasetID
+        from satpy import MultiScene
 
         area = _create_test_area()
         scenes = _create_test_scenes(area=area)
-        ds1_id = DatasetID(name='ds1')
-        ds2_id = DatasetID(name='ds2')
-        ds3_id = DatasetID(name='ds3')
-        ds4_id = DatasetID(name='ds4')
+        ds1_id = make_dataid(name='ds1')
+        ds2_id = make_dataid(name='ds2')
+        ds3_id = make_dataid(name='ds3')
+        ds4_id = make_dataid(name='ds4')
 
         # Add a dataset to only one of the Scenes
         scenes[1]['ds3'] = _create_test_dataset('ds3')
@@ -124,22 +155,60 @@ class TestMultiScene(unittest.TestCase):
     def test_from_files(self):
         """Test creating a multiscene from multiple files."""
         from satpy import MultiScene
-        input_files = [
+        input_files_abi = [
             "OR_ABI-L1b-RadC-M3C01_G16_s20171171502203_e20171171504576_c20171171505018.nc",
             "OR_ABI-L1b-RadC-M3C01_G16_s20171171507203_e20171171509576_c20171171510018.nc",
             "OR_ABI-L1b-RadC-M3C01_G16_s20171171512203_e20171171514576_c20171171515017.nc",
             "OR_ABI-L1b-RadC-M3C01_G16_s20171171517203_e20171171519577_c20171171520019.nc",
             "OR_ABI-L1b-RadC-M3C01_G16_s20171171522203_e20171171524576_c20171171525020.nc",
             "OR_ABI-L1b-RadC-M3C01_G16_s20171171527203_e20171171529576_c20171171530017.nc",
+            ]
+        input_files_glm = [
+            "OR_GLM-L2-GLMC-M3_G16_s20171171500000_e20171171501000_c20380190314080.nc",
+            "OR_GLM-L2-GLMC-M3_G16_s20171171501000_e20171171502000_c20380190314080.nc",
+            "OR_GLM-L2-GLMC-M3_G16_s20171171502000_e20171171503000_c20380190314080.nc",
+            "OR_GLM-L2-GLMC-M3_G16_s20171171503000_e20171171504000_c20380190314080.nc",
+            "OR_GLM-L2-GLMC-M3_G16_s20171171504000_e20171171505000_c20380190314080.nc",
+            "OR_GLM-L2-GLMC-M3_G16_s20171171505000_e20171171506000_c20380190314080.nc",
+            "OR_GLM-L2-GLMC-M3_G16_s20171171506000_e20171171507000_c20380190314080.nc",
+            "OR_GLM-L2-GLMC-M3_G16_s20171171507000_e20171171508000_c20380190314080.nc",
         ]
         with mock.patch('satpy.multiscene.Scene') as scn_mock:
-            mscn = MultiScene.from_files(input_files, reader='abi_l1b')
-            self.assertTrue(len(mscn.scenes), 6)
-            calls = [mock.call(filenames={'abi_l1b': [in_file]}) for in_file in input_files]
+            mscn = MultiScene.from_files(
+                    input_files_abi,
+                    reader='abi_l1b')
+            assert len(mscn.scenes) == 6
+            calls = [mock.call(
+                filenames={'abi_l1b': [in_file_abi]})
+                for in_file_abi in input_files_abi]
             scn_mock.assert_has_calls(calls)
 
+            scn_mock.reset_mock()
+            mscn = MultiScene.from_files(
+                    input_files_abi + input_files_glm,
+                    reader=('abi_l1b', "glm_l2"),
+                    group_keys=["start_time"],
+                    ensure_all_readers=True,
+                    time_threshold=30)
+            assert len(mscn.scenes) == 2
+            calls = [mock.call(
+                filenames={'abi_l1b': [in_file_abi], 'glm_l2': [in_file_glm]})
+                for (in_file_abi, in_file_glm) in
+                zip(input_files_abi[0:2],
+                    [input_files_glm[2]] + [input_files_glm[7]])]
+            scn_mock.assert_has_calls(calls)
+            scn_mock.reset_mock()
+            mscn = MultiScene.from_files(
+                    input_files_abi + input_files_glm,
+                    reader=('abi_l1b', "glm_l2"),
+                    group_keys=["start_time"],
+                    ensure_all_readers=False,
+                    time_threshold=30)
+            assert len(mscn.scenes) == 12
+
     def test_group(self):
-        from satpy import Scene, MultiScene, DatasetID
+        """Test group."""
+        from satpy import Scene, MultiScene
 
         ds1 = _create_test_dataset(name='ds1')
         ds2 = _create_test_dataset(name='ds2')
@@ -153,8 +222,8 @@ class TestMultiScene(unittest.TestCase):
         scene2['ds4'] = ds4
 
         multi_scene = MultiScene([scene1, scene2])
-        groups = {DatasetID(name='odd', wavelength=(1, 2, 3)): ['ds1', 'ds3'],
-                  DatasetID(name='even', wavelength=(2, 3, 4)): ['ds2', 'ds4']}
+        groups = {make_dataid(name='odd', wavelength=(1, 2, 3)): ['ds1', 'ds3'],
+                  make_dataid(name='even', wavelength=(2, 3, 4)): ['ds2', 'ds4']}
         multi_scene.group(groups)
 
         self.assertSetEqual(multi_scene.shared_dataset_ids, set(groups.keys()))
@@ -166,14 +235,13 @@ class TestMultiScene(unittest.TestCase):
         import types
 
         from satpy.multiscene import add_group_aliases
-        from satpy import DatasetID
         from satpy import Scene
 
         # Define test scenes
-        ds_id1 = DatasetID('ds1', wavelength=(10.7, 10.8, 10.9))
-        ds_id2 = DatasetID('ds2', wavelength=(1.9, 2.0, 2.1))
-        ds_id3 = DatasetID('ds3', wavelength=(10.8, 10.9, 11.0))
-        ds_id31 = DatasetID('ds31', polarization='H')
+        ds_id1 = make_dataid(name='ds1', wavelength=(10.7, 10.8, 10.9))
+        ds_id2 = make_dataid(name='ds2', wavelength=(1.9, 2.0, 2.1))
+        ds_id3 = make_dataid(name='ds3', wavelength=(10.8, 10.9, 11.0))
+        ds_id31 = make_dataid(name='ds31', polarization='H')
 
         scene1 = Scene()
         scene1[ds_id1] = xr.DataArray([1])
@@ -185,8 +253,8 @@ class TestMultiScene(unittest.TestCase):
         scenes = [scene1, scene2, scene3]
 
         # Define groups
-        g1 = DatasetID(name='g1', wavelength=(10, 11, 12))
-        g2 = DatasetID(name='g2', wavelength=(1, 2, 3), polarization='V')
+        g1 = make_dataid(name='g1', wavelength=(10, 11, 12))
+        g2 = make_dataid(name='g2', wavelength=(1, 2, 3), polarization='V')
         groups = {g1: ['ds1', 'ds3'], g2: ['ds2']}
 
         # Test adding aliases
@@ -227,58 +295,6 @@ class TestMultiSceneSave(unittest.TestCase):
         except OSError:
             pass
 
-    @mock.patch('satpy.multiscene.get_enhanced_image', _fake_get_enhanced_image)
-    def test_save_mp4(self):
-        """Save a series of fake scenes to an mp4 video."""
-        from satpy import MultiScene
-        area = _create_test_area()
-        scenes = _create_test_scenes(area=area)
-
-        # Add a dataset to only one of the Scenes
-        scenes[1]['ds3'] = _create_test_dataset('ds3')
-        # Add a start and end time
-        for ds_id in ['ds1', 'ds2', 'ds3']:
-            scenes[1][ds_id].attrs['start_time'] = datetime(2018, 1, 2)
-            scenes[1][ds_id].attrs['end_time'] = datetime(2018, 1, 2, 12)
-            if ds_id == 'ds3':
-                continue
-            scenes[0][ds_id].attrs['start_time'] = datetime(2018, 1, 1)
-            scenes[0][ds_id].attrs['end_time'] = datetime(2018, 1, 1, 12)
-
-        mscn = MultiScene(scenes)
-        fn = os.path.join(
-            self.base_dir,
-            'test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4')
-        writer_mock = mock.MagicMock()
-        with mock.patch('satpy.multiscene.imageio.get_writer') as get_writer:
-            get_writer.return_value = writer_mock
-            # force order of datasets by specifying them
-            mscn.save_animation(fn, datasets=['ds1', 'ds2', 'ds3'], client=False)
-
-        # 2 saves for the first scene + 1 black frame
-        # 3 for the second scene
-        self.assertEqual(writer_mock.append_data.call_count, 3 + 3)
-        filenames = [os.path.basename(args[0][0]) for args in get_writer.call_args_list]
-        self.assertEqual(filenames[0], 'test_save_mp4_ds1_20180101_00_20180102_12.mp4')
-        self.assertEqual(filenames[1], 'test_save_mp4_ds2_20180101_00_20180102_12.mp4')
-        self.assertEqual(filenames[2], 'test_save_mp4_ds3_20180102_00_20180102_12.mp4')
-
-        # make sure that not specifying datasets still saves all of them
-        fn = os.path.join(
-            self.base_dir,
-            'test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4')
-        writer_mock = mock.MagicMock()
-        with mock.patch('satpy.multiscene.imageio.get_writer') as get_writer:
-            get_writer.return_value = writer_mock
-            # force order of datasets by specifying them
-            mscn.save_animation(fn, client=False)
-        # the 'ds3' dataset isn't known to the first scene so it doesn't get saved
-        # 2 for first scene, 2 for second scene
-        self.assertEqual(writer_mock.append_data.call_count, 2 + 2)
-        self.assertIn('test_save_mp4_ds1_20180101_00_20180102_12.mp4', filenames)
-        self.assertIn('test_save_mp4_ds2_20180101_00_20180102_12.mp4', filenames)
-        self.assertIn('test_save_mp4_ds3_20180102_00_20180102_12.mp4', filenames)
-
     @mock.patch('satpy.multiscene.get_enhanced_image', _fake_get_enhanced_image)
     def test_save_mp4_distributed(self):
         """Save a series of fake scenes to an mp4 video."""
@@ -531,3 +547,74 @@ class TestBlendFuncs(unittest.TestCase):
         self.assertIsInstance(res2, xr.DataArray)
         self.assertTupleEqual((2, self.ds1.shape[0], self.ds1.shape[1]), res.shape)
         self.assertTupleEqual((self.ds3.shape[0], self.ds3.shape[1]+self.ds4.shape[1]), res2.shape)
+
+
+@mock.patch('satpy.multiscene.get_enhanced_image')
+def test_save_mp4(smg, tmp_path):
+    """Save a series of fake scenes to an mp4 video."""
+    from satpy import MultiScene
+    area = _create_test_area()
+    scenes = _create_test_scenes(area=area)
+    smg.side_effect = _fake_get_enhanced_image
+
+    # Add a dataset to only one of the Scenes
+    scenes[1]['ds3'] = _create_test_dataset('ds3')
+    # Add a start and end time
+    for ds_id in ['ds1', 'ds2', 'ds3']:
+        scenes[1][ds_id].attrs['start_time'] = datetime(2018, 1, 2)
+        scenes[1][ds_id].attrs['end_time'] = datetime(2018, 1, 2, 12)
+        if ds_id == 'ds3':
+            continue
+        scenes[0][ds_id].attrs['start_time'] = datetime(2018, 1, 1)
+        scenes[0][ds_id].attrs['end_time'] = datetime(2018, 1, 1, 12)
+
+    mscn = MultiScene(scenes)
+    fn = str(tmp_path /
+             'test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4')
+    writer_mock = mock.MagicMock()
+    with mock.patch('satpy.multiscene.imageio.get_writer') as get_writer:
+        get_writer.return_value = writer_mock
+        # force order of datasets by specifying them
+        mscn.save_animation(fn, datasets=['ds1', 'ds2', 'ds3'], client=False)
+
+    # 2 saves for the first scene + 1 black frame
+    # 3 for the second scene
+    assert writer_mock.append_data.call_count == 3 + 3
+    filenames = [os.path.basename(args[0][0]) for args in get_writer.call_args_list]
+    assert filenames[0] == 'test_save_mp4_ds1_20180101_00_20180102_12.mp4'
+    assert filenames[1] == 'test_save_mp4_ds2_20180101_00_20180102_12.mp4'
+    assert filenames[2] == 'test_save_mp4_ds3_20180102_00_20180102_12.mp4'
+
+    # make sure that not specifying datasets still saves all of them
+    fn = str(tmp_path /
+             'test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4')
+    writer_mock = mock.MagicMock()
+    with mock.patch('satpy.multiscene.imageio.get_writer') as get_writer:
+        get_writer.return_value = writer_mock
+        # force order of datasets by specifying them
+        mscn.save_animation(fn, client=False)
+    # the 'ds3' dataset isn't known to the first scene so it doesn't get saved
+    # 2 for first scene, 2 for second scene
+    assert writer_mock.append_data.call_count == 2 + 2
+    assert "test_save_mp4_ds1_20180101_00_20180102_12.mp4" in filenames
+    assert "test_save_mp4_ds2_20180101_00_20180102_12.mp4" in filenames
+    assert "test_save_mp4_ds3_20180102_00_20180102_12.mp4" in filenames
+
+    # test decorating and enhancing
+
+    fn = str(tmp_path /
+             'test-{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}-rich.mp4')
+    writer_mock = mock.MagicMock()
+    with mock.patch('satpy.multiscene.imageio.get_writer') as get_writer:
+        get_writer.return_value = writer_mock
+        mscn.save_animation(
+                fn, client=False,
+                enh_args={"decorate": {
+                    "decorate": [{
+                        "text": {
+                            "txt":
+                            "Test {start_time:%Y-%m-%d %H:%M} - "
+                            "{end_time:%Y-%m-%d %H:%M}"}}]}})
+    assert writer_mock.append_data.call_count == 2 + 2
+    assert ("2018-01-02" in smg.call_args_list[-1][1]
+            ["decorate"]["decorate"][0]["text"]["txt"])
