@@ -27,12 +27,12 @@ class TestMITIFFWriter(unittest.TestCase):
     """Test the MITIFF Writer class."""
 
     def setUp(self):
-        """Create temporary directory to save files to"""
+        """Create temporary directory to save files to."""
         import tempfile
         self.base_dir = tempfile.mkdtemp()
 
     def tearDown(self):
-        """Remove the temporary directory created for a test"""
+        """Remove the temporary directory created for a test."""
         try:
             import shutil
             shutil.rmtree(self.base_dir, ignore_errors=True)
@@ -40,7 +40,7 @@ class TestMITIFFWriter(unittest.TestCase):
             pass
 
     def _get_test_datasets(self):
-        """Helper function to create a datasets list."""
+        """Create a datasets list."""
         import xarray as xr
         import dask.array as da
         from datetime import datetime
@@ -106,7 +106,7 @@ class TestMITIFFWriter(unittest.TestCase):
         return [ds1, ds2]
 
     def _get_test_datasets_sensor_set(self):
-        """Helper function to create a datasets list."""
+        """Create a datasets list."""
         import xarray as xr
         import dask.array as da
         from datetime import datetime
@@ -172,7 +172,7 @@ class TestMITIFFWriter(unittest.TestCase):
         return [ds1, ds2]
 
     def _get_test_dataset(self, bands=3):
-        """Helper function to create a single test dataset."""
+        """Create a single test dataset."""
         import xarray as xr
         import dask.array as da
         from datetime import datetime
@@ -202,7 +202,7 @@ class TestMITIFFWriter(unittest.TestCase):
         return ds1
 
     def _get_test_one_dataset(self):
-        """Helper function to create a single test dataset."""
+        """Create a single test dataset."""
         import xarray as xr
         import dask.array as da
         from datetime import datetime
@@ -232,7 +232,7 @@ class TestMITIFFWriter(unittest.TestCase):
         return ds1
 
     def _get_test_one_dataset_sensor_set(self):
-        """Helper function to create a single test dataset."""
+        """Create a single test dataset."""
         import xarray as xr
         import dask.array as da
         from datetime import datetime
@@ -262,7 +262,7 @@ class TestMITIFFWriter(unittest.TestCase):
         return ds1
 
     def _get_test_dataset_with_bad_values(self, bands=3):
-        """Helper function to create a single test dataset."""
+        """Create a single test dataset."""
         import xarray as xr
         import numpy as np
         from datetime import datetime
@@ -296,13 +296,13 @@ class TestMITIFFWriter(unittest.TestCase):
         return ds1
 
     def _get_test_dataset_calibration(self, bands=6):
-        """Helper function to create a single test dataset."""
+        """Create a single test dataset."""
         import xarray as xr
         import dask.array as da
         from datetime import datetime
         from pyresample.geometry import AreaDefinition
         from pyresample.utils import proj4_str_to_dict
-        from satpy import DatasetID
+        from satpy.tests.utils import make_dsq
         from satpy.scene import Scene
         area_def = AreaDefinition(
             'test',
@@ -315,13 +315,13 @@ class TestMITIFFWriter(unittest.TestCase):
             (-1000., -1500., 1000., 1500.),
         )
 
-        d = [
-            DatasetID(name='1', calibration='reflectance'),
-            DatasetID(name='2', calibration='reflectance'),
-            DatasetID(name='3', calibration='brightness_temperature'),
-            DatasetID(name='4', calibration='brightness_temperature'),
-            DatasetID(name='5', calibration='brightness_temperature'),
-            DatasetID(name='6', calibration='reflectance')
+        prereqs = [
+            make_dsq(name='1', calibration='reflectance'),
+            make_dsq(name='2', calibration='reflectance'),
+            make_dsq(name='3', calibration='brightness_temperature'),
+            make_dsq(name='4', calibration='brightness_temperature'),
+            make_dsq(name='5', calibration='brightness_temperature'),
+            make_dsq(name='6', calibration='reflectance')
         ]
         scene = Scene()
         scene["1"] = xr.DataArray(da.zeros((100, 200), chunks=50),
@@ -355,7 +355,7 @@ class TestMITIFFWriter(unittest.TestCase):
                      'platform_name': "TEST_PLATFORM_NAME",
                      'sensor': 'test-sensor',
                      'area': area_def,
-                     'prerequisites': d,
+                     'prerequisites': prereqs,
                      'metadata_requirements': {
                          'order': ['1', '2', '3', '4', '5', '6'],
                          'config': {
@@ -399,13 +399,13 @@ class TestMITIFFWriter(unittest.TestCase):
         return ds1
 
     def _get_test_dataset_calibration_one_dataset(self, bands=1):
-        """Helper function to create a single test dataset."""
+        """Create a single test dataset."""
         import xarray as xr
         import dask.array as da
         from datetime import datetime
         from pyresample.geometry import AreaDefinition
         from pyresample.utils import proj4_str_to_dict
-        from satpy import DatasetID
+        from satpy.tests.utils import make_dsq
         from satpy.scene import Scene
         area_def = AreaDefinition(
             'test',
@@ -418,7 +418,7 @@ class TestMITIFFWriter(unittest.TestCase):
             (-1000., -1500., 1000., 1500.),
         )
 
-        d = [DatasetID(name='4', calibration='brightness_temperature')]
+        prereqs = [make_dsq(name='4', calibration='brightness_temperature')]
         scene = Scene()
         scene["4"] = xr.DataArray(da.zeros((100, 200), chunks=50),
                                   dims=('y', 'x'),
@@ -433,7 +433,7 @@ class TestMITIFFWriter(unittest.TestCase):
                      'platform_name': "TEST_PLATFORM_NAME",
                      'sensor': 'test-sensor',
                      'area': area_def,
-                     'prerequisites': d,
+                     'prerequisites': prereqs,
                      'metadata_requirements': {
                          'order': ['4'],
                          'config': {
@@ -452,13 +452,13 @@ class TestMITIFFWriter(unittest.TestCase):
         return ds1
 
     def _get_test_dataset_three_bands_two_prereq(self, bands=3):
-        """Helper function to create a single test dataset."""
+        """Create a single test dataset."""
         import xarray as xr
         import dask.array as da
         from datetime import datetime
         from pyresample.geometry import AreaDefinition
         from pyresample.utils import proj4_str_to_dict
-        from satpy import DatasetID
+        from satpy.tests.utils import make_dsq
         area_def = AreaDefinition(
             'test',
             'test',
@@ -479,8 +479,8 @@ class TestMITIFFWriter(unittest.TestCase):
                    'platform_name': "TEST_PLATFORM_NAME",
                    'sensor': 'TEST_SENSOR_NAME',
                    'area': area_def,
-                   'prerequisites': [DatasetID(name='1', calibration='reflectance'),
-                                     DatasetID(name='2', calibration='reflectance')]}
+                   'prerequisites': [make_dsq(name='1', calibration='reflectance'),
+                                     make_dsq(name='2', calibration='reflectance')]}
         )
         return ds1
 
@@ -803,6 +803,7 @@ class TestMITIFFWriter(unittest.TestCase):
             np.testing.assert_allclose(image, expected, atol=1.e-6, rtol=0)
 
     def test_convert_proj4_string(self):
+        """Test conversion of geolocations."""
         import xarray as xr
         import dask.array as da
         from satpy.writers.mitiff import MITIFFWriter
@@ -936,7 +937,7 @@ class TestMITIFFWriter(unittest.TestCase):
             np.testing.assert_allclose(image, expected, atol=1.e-6, rtol=0)
 
     def test_simple_write_two_bands(self):
-        """Test basic writer operation with 3 bands from 2 prerequisites"""
+        """Test basic writer operation with 3 bands from 2 prerequisites."""
         from satpy.writers.mitiff import MITIFFWriter
         dataset = self._get_test_dataset_three_bands_two_prereq()
         w = MITIFFWriter(base_dir=self.base_dir)
